@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: cli.c 10640 2010-05-11 13:36:21Z charles $
+ * $Id: cli.c 11335 2010-10-18 03:11:51Z charles $
  *
  * Copyright (c) 2005-2006 Transmission authors and contributors
  *
@@ -30,54 +30,69 @@
 
 #include <libtransmission/transmission.h>
 #include <libtransmission/bencode.h>
-#include <libtransmission/makemeta.h>
 #include <libtransmission/tr-getopt.h>
 #include <libtransmission/utils.h> /* tr_wait_msec */
 #include <libtransmission/version.h>
 #include <libtransmission/web.h> /* tr_webRun */
 
-#define LINEWIDTH 80
-#define MY_NAME "transmissioncli"
+/***
+****
+***/
 
-static tr_bool showInfo         = 0;
-static tr_bool showScrape       = 0;
-static tr_bool isPrivate        = 0;
-static tr_bool verify           = 0;
+#define MEM_K 1024
+#define MEM_K_STR "KiB"
+#define MEM_M_STR "MiB"
+#define MEM_G_STR "GiB"
+#define MEM_T_STR "TiB"
+
+#define DISK_K 1024
+#define DISK_B_STR   "B"
+#define DISK_K_STR "KiB"
+#define DISK_M_STR "MiB"
+#define DISK_G_STR "GiB"
+#define DISK_T_STR "TiB"
+
+#define SPEED_K 1024
+#define SPEED_B_STR   "B/s"
+#define SPEED_K_STR "KiB/s"
+#define SPEED_M_STR "MiB/s"
+#define SPEED_G_STR "GiB/s"
+#define SPEED_T_STR "TiB/s"
+
+/***
+****
+***/
+
+#define LINEWIDTH 80
+#define MY_CONFIG_NAME "transmission"
+#define MY_READABLE_NAME "transmission-cli"
+
+static tr_bool showVersion = FALSE;
+static tr_bool verify                = 0;
 static sig_atomic_t gotsig           = 0;
 static sig_atomic_t manualUpdate     = 0;
 
 static const char * torrentPath  = NULL;
-static const char * sourceFile   = NULL;
-static const char * comment      = NULL;
-
-#define MAX_ANNOUNCE 128
-static tr_tracker_info announce[MAX_ANNOUNCE];
-static int announceCount = 0;
 
 static const struct tr_option options[] =
 {
-    { 'a', "announce",             "Set the new torrent's announce URL", "a",  1, "<url>"     },
-    { 'b', "blocklist",            "Enable peer blocklists", "b",  0, NULL        },
-    { 'B', "no-blocklist",         "Disable peer blocklists", "B",  0, NULL        },
-    { 'c', "comment",              "Set the new torrent's comment", "c",  1, "<comment>" },
-    { 'd', "downlimit",            "Set max download speed in KiB/s", "d",  1, "<speed>"   },
-    { 'D', "no-downlimit",         "Don't limit the download speed", "D",  0, NULL        },
-    { 910, "encryption-required",  "Encrypt all peer connections", "er", 0, NULL        },
-    { 911, "encryption-preferred", "Prefer encrypted peer connections", "ep", 0, NULL        },
-    { 912, "encryption-tolerated", "Prefer unencrypted peer connections", "et", 0, NULL        },
+    { 'b', "blocklist",            "Enable peer blocklists", "b",  0, NULL },
+    { 'B', "no-blocklist",         "Disable peer blocklists", "B",  0, NULL },
+    { 'd', "downlimit",            "Set max download speed in "SPEED_K_STR, "d",  1, "<speed>" },
+    { 'D', "no-downlimit",         "Don't limit the download speed", "D",  0, NULL },
+    { 910, "encryption-required",  "Encrypt all peer connections", "er", 0, NULL },
+    { 911, "encryption-preferred", "Prefer encrypted peer connections", "ep", 0, NULL },
+    { 912, "encryption-tolerated", "Prefer unencrypted peer connections", "et", 0, NULL },
     { 'f', "finish",               "Run a script when the torrent finishes", "f", 1, "<script>" },
     { 'g', "config-dir",           "Where to find configuration files", "g", 1, "<path>" },
-    { 'i', "info",                 "Show torrent details and exit", "i",  0, NULL        },
-    { 'm', "portmap",              "Enable portmapping via NAT-PMP or UPnP", "m",  0, NULL        },
-    { 'M', "no-portmap",           "Disable portmapping", "M",  0, NULL        },
-    { 'n', "new",                  "Create a new torrent", "n", 1, "<source>" },
+    { 'm', "portmap",              "Enable portmapping via NAT-PMP or UPnP", "m",  0, NULL },
+    { 'M', "no-portmap",           "Disable portmapping", "M",  0, NULL },
     { 'p', "port", "Port for incoming peers (Default: " TR_DEFAULT_PEER_PORT_STR ")", "p", 1, "<port>" },
-    { 'r', "private",              "Set the new torrent's 'private' flag", "r",  0, NULL        },
-    { 's', "scrape",               "Scrape the torrent and exit", "s",  0, NULL        },
     { 't', "tos", "Peer socket TOS (0 to 255, default=" TR_DEFAULT_PEER_SOCKET_TOS_STR ")", "t", 1, "<tos>" },
-    { 'u', "uplimit",              "Set max upload speed in KiB/s", "u",  1, "<speed>"   },
+    { 'u', "uplimit",              "Set max upload speed in "SPEED_K_STR, "u",  1, "<speed>"   },
     { 'U', "no-uplimit",           "Don't limit the upload speed", "U",  0, NULL        },
     { 'v', "verify",               "Verify the specified torrent", "v",  0, NULL        },
+    { 'V', "version",              "Show version number and exit", "V", 0, NULL },
     { 'w', "download-dir",         "Where to save downloaded data", "w",  1, "<path>"    },
     { 0, NULL, NULL, NULL, 0, NULL }
 };
@@ -87,7 +102,7 @@ getUsage( void )
 {
     return "A fast and easy BitTorrent client\n"
            "\n"
-           "Usage: " MY_NAME " [options] <file|url|magnet>";
+           "Usage: " MY_READABLE_NAME " [options] <file|url|magnet>";
 }
 
 static int parseCommandLine( tr_benc*, int argc, const char ** argv );
@@ -112,30 +127,6 @@ tr_strlratio( char * buf,
     return buf;
 }
 
-static int
-is_rfc2396_alnum( char ch )
-{
-    return ( '0' <= ch && ch <= '9' )
-           || ( 'A' <= ch && ch <= 'Z' )
-           || ( 'a' <= ch && ch <= 'z' );
-}
-
-static void
-escape( char *          out,
-        const uint8_t * in,
-        int             in_len )                     /* rfc2396 */
-{
-    const uint8_t *end = in + in_len;
-
-    while( in != end )
-        if( is_rfc2396_alnum( *in ) )
-            *out++ = (char) *in++;
-        else
-            out += tr_snprintf( out, 4, "%%%02X", (unsigned int)*in++ );
-
-    *out = '\0';
-}
-
 static tr_bool waitingOnWeb;
 
 static void
@@ -149,83 +140,6 @@ onTorrentFileDownloaded( tr_session   * session UNUSED,
     waitingOnWeb = FALSE;
 }
 
-static int leftToScrape = 0;
-
-static void
-scrapeDoneFunc( tr_session   * session UNUSED,
-                long           response_code,
-                const void   * response,
-                size_t         response_byte_count,
-                void         * host )
-{
-    tr_benc top, *files;
-
-    if( !tr_bencLoad( response, response_byte_count, &top, NULL )
-      && tr_bencDictFindDict( &top, "files", &files )
-      && files->val.l.count >= 2 )
-    {
-        int64_t   complete = -1, incomplete = -1, downloaded = -1;
-        tr_benc * hash = &files->val.l.vals[1];
-        tr_bencDictFindInt( hash, "complete", &complete );
-        tr_bencDictFindInt( hash, "incomplete", &incomplete );
-        tr_bencDictFindInt( hash, "downloaded", &downloaded );
-        printf( "%4d seeders, %4d leechers, %5d downloads at %s\n",
-                (int)complete, (int)incomplete, (int)downloaded,
-                (char*)host );
-        tr_bencFree( &top );
-    }
-    else
-        fprintf( stderr, "Unable to parse response (http code %lu) at %s",
-                 response_code,
-                 (char*)host );
-
-    --leftToScrape;
-
-    tr_free( host );
-}
-
-static void
-dumpInfo( FILE *          out,
-          const tr_info * inf )
-{
-    int             i;
-    int             prevTier = -1;
-    tr_file_index_t ff;
-
-    fprintf( out, "hash:\t" );
-    for( i = 0; i < SHA_DIGEST_LENGTH; ++i )
-        fprintf( out, "%02x", inf->hash[i] );
-    fprintf( out, "\n" );
-
-    fprintf( out, "name:\t%s\n", inf->name );
-
-    for( i = 0; i < inf->trackerCount; ++i )
-    {
-        if( prevTier != inf->trackers[i].tier )
-        {
-            prevTier = inf->trackers[i].tier;
-            fprintf( out, "\ntracker tier #%d:\n", ( prevTier + 1 ) );
-        }
-        fprintf( out, "\tannounce:\t%s\n", inf->trackers[i].announce );
-    }
-
-    fprintf( out, "size:\t%" PRIu64 " (%" PRIu64 " * %d + %" PRIu64 ")\n",
-             inf->totalSize, inf->totalSize / inf->pieceSize,
-             inf->pieceSize, inf->totalSize % inf->pieceSize );
-
-    if( inf->comment && *inf->comment )
-        fprintf( out, "comment:\t%s\n", inf->comment );
-    if( inf->creator && *inf->creator )
-        fprintf( out, "creator:\t%s\n", inf->creator );
-    if( inf->isPrivate )
-        fprintf( out, "private flag set\n" );
-
-    fprintf( out, "file(s):\n" );
-    for( ff = 0; ff < inf->fileCount; ++ff )
-        fprintf( out, "\t%s (%" PRIu64 ")\n", inf->files[ff].name,
-                 inf->files[ff].length );
-}
-
 static void
 getStatusStr( const tr_stat * st,
               char *          buf,
@@ -244,29 +158,35 @@ getStatusStr( const tr_stat * st,
     }
     else if( st->activity & TR_STATUS_DOWNLOAD )
     {
+        char upStr[80];
+        char dnStr[80];
         char ratioStr[80];
+
+        tr_formatter_speed_KBps( upStr, st->pieceUploadSpeed_KBps, sizeof( upStr ) );
+        tr_formatter_speed_KBps( dnStr, st->pieceDownloadSpeed_KBps, sizeof( dnStr ) );
         tr_strlratio( ratioStr, st->ratio, sizeof( ratioStr ) );
-        tr_snprintf(
-            buf, buflen,
-            "Progress: %.1f%%, dl from %d of %d peers (%.0f KiB/s), "
-            "ul to %d (%.0f KiB/s) [%s]",
+
+        tr_snprintf( buf, buflen,
+            "Progress: %.1f%%, "
+            "dl from %d of %d peers (%s), "
+            "ul to %d (%s) "
+            "[%s]",
             tr_truncd( 100 * st->percentDone, 1 ),
-            st->peersSendingToUs,
-            st->peersConnected,
-            st->pieceDownloadSpeed,
-            st->peersGettingFromUs,
-            st->pieceUploadSpeed,
+            st->peersSendingToUs, st->peersConnected, upStr,
+            st->peersGettingFromUs, dnStr,
             ratioStr );
     }
     else if( st->activity & TR_STATUS_SEED )
     {
+        char upStr[80];
         char ratioStr[80];
+
+        tr_formatter_speed_KBps( upStr, st->pieceUploadSpeed_KBps, sizeof( upStr ) );
         tr_strlratio( ratioStr, st->ratio, sizeof( ratioStr ) );
-        tr_snprintf(
-            buf, buflen,
-            "Seeding, uploading to %d of %d peer(s), %.0f KiB/s [%s]",
-            st->peersGettingFromUs, st->peersConnected,
-            st->pieceUploadSpeed, ratioStr );
+
+        tr_snprintf( buf, buflen,
+                     "Seeding, uploading to %d of %d peer(s), %s [%s]",
+                     st->peersGettingFromUs, st->peersConnected, upStr, ratioStr );
     }
     else *buf = '\0';
 }
@@ -289,14 +209,13 @@ getConfigDir( int argc, const char ** argv )
     tr_optind = ind;
 
     if( configDir == NULL )
-        configDir = tr_getDefaultConfigDir( MY_NAME );
+        configDir = tr_getDefaultConfigDir( MY_CONFIG_NAME );
 
     return configDir;
 }
 
 int
-main( int     argc,
-      char ** argv )
+main( int argc, char ** argv )
 {
     int           error;
     tr_session  * h;
@@ -304,71 +223,45 @@ main( int     argc,
     tr_torrent  * tor = NULL;
     tr_benc       settings;
     const char  * configDir;
-    tr_bool       haveSource;
-    tr_bool       haveAnnounce;
     uint8_t     * fileContents;
     size_t        fileLength;
 
-    printf( "Transmission %s - http://www.transmissionbt.com/\n",
-            LONG_VERSION_STRING );
+    tr_formatter_mem_init( MEM_K, MEM_K_STR, MEM_M_STR, MEM_G_STR, MEM_T_STR );
+    tr_formatter_size_init( DISK_K,DISK_K_STR, DISK_M_STR, DISK_G_STR, DISK_T_STR );
+    tr_formatter_speed_init( SPEED_K, SPEED_K_STR, SPEED_M_STR, SPEED_G_STR, SPEED_T_STR );
+
+    printf( "%s %s\n", MY_READABLE_NAME, LONG_VERSION_STRING );
 
     /* user needs to pass in at least one argument */
     if( argc < 2 ) {
-        tr_getopt_usage( MY_NAME, getUsage( ), options );
+        tr_getopt_usage( MY_READABLE_NAME, getUsage( ), options );
         return EXIT_FAILURE;
     }
 
     /* load the defaults from config file + libtransmission defaults */
     tr_bencInitDict( &settings, 0 );
     configDir = getConfigDir( argc, (const char**)argv );
-    tr_sessionLoadSettings( &settings, configDir, MY_NAME );
+    tr_sessionLoadSettings( &settings, configDir, MY_CONFIG_NAME );
 
     /* the command line overrides defaults */
     if( parseCommandLine( &settings, argc, (const char**)argv ) )
         return EXIT_FAILURE;
 
+    if( showVersion )
+        return 0;
+
     /* Check the options for validity */
     if( !torrentPath ) {
         fprintf( stderr, "No torrent specified!\n" );
         return EXIT_FAILURE;
     }
 
-    /* don't bind the port if we're just running the CLI
-       to get metainfo or to create a torrent */
-    if( showInfo || showScrape || ( sourceFile != NULL ) )
-        tr_bencDictAddInt( &settings, TR_PREFS_KEY_PEER_PORT, -1 );
-
     h = tr_sessionInit( "cli", configDir, FALSE, &settings );
 
-    haveSource = sourceFile && *sourceFile;
-    haveAnnounce = announceCount > 0;
-
-    if( haveSource && !haveAnnounce )
-        fprintf( stderr, "Did you mean to create a torrent without a tracker's announce URL?\n" );
-
-    if( haveSource ) /* creating a torrent */
-    {
-        int err;
-        tr_metainfo_builder * b;
-        fprintf( stderr, "creating torrent \"%s\"\n", torrentPath );
-
-        b = tr_metaInfoBuilderCreate( sourceFile );
-        tr_makeMetaInfo( b, torrentPath, announce, announceCount, comment, isPrivate );
-        while( !b->isDone )
-        {
-            tr_wait_msec( 1000 );
-            printf( "." );
-        }
-
-        err = b->result;
-        tr_metaInfoBuilderFree( b );
-        return err;
-    }
-
     ctor = tr_ctorNew( h );
 
     fileContents = tr_loadFile( torrentPath, &fileLength );
-    tr_ctorSetPaused( ctor, TR_FORCE, showScrape );
+    tr_ctorSetPaused( ctor, TR_FORCE, FALSE );
     if( fileContents != NULL ) {
         tr_ctorSetMetainfo( ctor, fileContents, fileLength );
     } else if( !memcmp( torrentPath, "magnet:?", 8 ) ) {
@@ -377,60 +270,15 @@ main( int     argc,
         tr_webRun( h, torrentPath, NULL, onTorrentFileDownloaded, ctor );
         waitingOnWeb = TRUE;
         while( waitingOnWeb ) tr_wait_msec( 1000 );
+    } else {
+        fprintf( stderr, "ERROR: Unrecognized torrent \"%s\".\n", torrentPath );
+        fprintf( stderr, " * If you're trying to create a torrent, use transmission-create.\n" );
+        fprintf( stderr, " * If you're trying to see a torrent's info, use transmission-show.\n" );
+        tr_sessionClose( h );
+        return EXIT_FAILURE;
     }
     tr_free( fileContents );
 
-    if( showScrape )
-    {
-        tr_info info;
-
-        if( !tr_torrentParse( ctor, &info ) )
-        {
-            int          i;
-            const time_t start = time( NULL );
-            for( i = 0; i < info.trackerCount; ++i )
-            {
-                if( info.trackers[i].scrape )
-                {
-                    const char * scrape = info.trackers[i].scrape;
-                    char         escaped[SHA_DIGEST_LENGTH * 3 + 1];
-                    char *       url, *host;
-                    escape( escaped, info.hash, SHA_DIGEST_LENGTH );
-                    url = tr_strdup_printf( "%s%cinfo_hash=%s",
-                                            scrape,
-                                            strchr( scrape,
-                                                    '?' ) ? '&' : '?',
-                                            escaped );
-                    tr_urlParse( scrape, -1, NULL, &host, NULL, NULL );
-                    ++leftToScrape;
-
-                    tr_webRun( h, url, NULL, scrapeDoneFunc, host );
-                    tr_free( url );
-                }
-            }
-
-            fprintf( stderr, "scraping %d trackers:\n", leftToScrape );
-
-            while( leftToScrape > 0 && ( ( time( NULL ) - start ) < 20 ) )
-                tr_wait_msec( 250 );
-        }
-        goto cleanup;
-    }
-
-    if( showInfo )
-    {
-        tr_info info;
-
-        if( !tr_torrentParse( ctor, &info ) )
-        {
-            dumpInfo( stdout, &info );
-            tr_metainfoFree( &info );
-        }
-
-        tr_ctorFree( ctor );
-        goto cleanup;
-    }
-
     tor = tr_torrentNew( ctor, &error );
     tr_ctorFree( ctor );
     if( !tor )
@@ -495,8 +343,6 @@ main( int     argc,
             fprintf( stderr, "\n%s: %s\n", messageName[st->error], st->errorString );
     }
 
-cleanup:
-
     tr_sessionSaveSettings( h, configDir, &settings );
 
     printf( "\n" );
@@ -521,19 +367,11 @@ parseCommandLine( tr_benc * d, int argc, const char ** argv )
     {
         switch( c )
         {
-            case 'a': if( announceCount + 1 < MAX_ANNOUNCE ) {
-                          announce[announceCount].tier = announceCount;
-                          announce[announceCount].announce = (char*) optarg;
-                          ++announceCount;
-                      }
-                      break;
             case 'b': tr_bencDictAddBool( d, TR_PREFS_KEY_BLOCKLIST_ENABLED, TRUE );
                       break;
             case 'B': tr_bencDictAddBool( d, TR_PREFS_KEY_BLOCKLIST_ENABLED, FALSE );
                       break;
-            case 'c': comment = optarg;
-                      break;
-            case 'd': tr_bencDictAddInt ( d, TR_PREFS_KEY_DSPEED, atoi( optarg ) );
+            case 'd': tr_bencDictAddInt ( d, TR_PREFS_KEY_DSPEED_KBps, atoi( optarg ) );
                       tr_bencDictAddBool( d, TR_PREFS_KEY_DSPEED_ENABLED, TRUE );
                       break;
             case 'D': tr_bencDictAddBool( d, TR_PREFS_KEY_DSPEED_ENABLED, FALSE );
@@ -543,27 +381,22 @@ parseCommandLine( tr_benc * d, int argc, const char ** argv )
                       break;
             case 'g': /* handled above */
                       break;
-            case 'i': showInfo = 1;
-                      break;
             case 'm': tr_bencDictAddBool( d, TR_PREFS_KEY_PORT_FORWARDING, TRUE );
                       break;
             case 'M': tr_bencDictAddBool( d, TR_PREFS_KEY_PORT_FORWARDING, FALSE );
                       break;
-            case 'n': sourceFile = optarg; break;
             case 'p': tr_bencDictAddInt( d, TR_PREFS_KEY_PEER_PORT, atoi( optarg ) );
                       break;
-            case 'r': isPrivate = 1;
-                      break;
-            case 's': showScrape = 1;
-                      break;
             case 't': tr_bencDictAddInt( d, TR_PREFS_KEY_PEER_SOCKET_TOS, atoi( optarg ) );
                       break;
-            case 'u': tr_bencDictAddInt( d, TR_PREFS_KEY_USPEED, atoi( optarg ) );
+            case 'u': tr_bencDictAddInt( d, TR_PREFS_KEY_USPEED_KBps, atoi( optarg ) );
                       tr_bencDictAddBool( d, TR_PREFS_KEY_USPEED_ENABLED, TRUE );
                       break;
             case 'U': tr_bencDictAddBool( d, TR_PREFS_KEY_USPEED_ENABLED, FALSE );
                       break;
-            case 'v': verify = 1;
+            case 'v': verify = TRUE;
+                      break;
+            case 'V': showVersion = TRUE;
                       break;
             case 'w': tr_bencDictAddStr( d, TR_PREFS_KEY_DOWNLOAD_DIR, optarg );
                       break;
@@ -574,7 +407,8 @@ parseCommandLine( tr_benc * d, int argc, const char ** argv )
             case 912: tr_bencDictAddInt( d, TR_PREFS_KEY_ENCRYPTION, TR_CLEAR_PREFERRED );
                       break;
             case TR_OPT_UNK:
-                      torrentPath = optarg;
+                      if( torrentPath == NULL )
+                          torrentPath = optarg;
                       break;
             default: return 1;
         }
