@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: add-dialog.c 10644 2010-05-13 13:12:27Z charles $
+ * $Id: add-dialog.c 11350 2010-10-24 05:52:38Z charles $
  */
 
 #include <glib/gi18n.h>
@@ -125,7 +125,7 @@ addResponseCB( GtkDialog * dialog,
         {
             tr_torrent * tor = tr_torrent_handle( data->gtor );
 
-            tr_torrentSetPriority( tor, gtr_priority_combo_get_value( data->priority_combo ) );
+            tr_torrentSetPriority( tor, gtr_priority_combo_get_value( GTK_COMBO_BOX( data->priority_combo ) ) );
 
             if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( data->run_check ) ) )
                 tr_torrentStart( tor );
@@ -297,8 +297,8 @@ addSingleTorrentDialog( GtkWindow * parent, TrCore * core, tr_ctor * ctor )
     str = _( "_Start when added" );
     data->run_check = gtk_check_button_new_with_mnemonic( str );
 
-    data->priority_combo = gtr_priority_combo_new( );
-    gtr_priority_combo_set_value( data->priority_combo, TR_PRI_NORMAL );
+    w = data->priority_combo = gtr_priority_combo_new( );
+    gtr_priority_combo_set_value( GTK_COMBO_BOX( w ), TR_PRI_NORMAL );
 
     g_signal_connect( G_OBJECT( d ), "response",
                       G_CALLBACK( addResponseCB ), data );
@@ -373,10 +373,6 @@ addSingleTorrentDialog( GtkWindow * parent, TrCore * core, tr_ctor * ctor )
     gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( w ), flag );
     gtk_table_attach( GTK_TABLE( t ), w, col, col + 2, row, row + 1, GTK_FILL, 0, 0, 0 );
 
-    ++row;
-    col = 0;
-    w = data->priority_combo;
-
     /* trigger sourceChanged, either directly or indirectly,
      * so that it creates the tor/gtor objects */
     w = source_chooser;
@@ -544,6 +540,7 @@ addURLDialog( GtkWindow * parent, TrCore * core )
     t = hig_workarea_create( );
     hig_workarea_add_section_title( t, &row, _( "Add torrent from URL" ) );
     e = gtk_entry_new( );
+    gtk_widget_set_size_request( e, 400, -1 );
     paste_clipboard_url_into_entry( e );
     g_object_set_data( G_OBJECT( w ), "url-entry", e );
     hig_workarea_add_row( t, &row, _( "_URL" ), e, NULL );
