@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: dialogs.c 8656 2009-06-09 04:52:22Z charles $
+ * $Id: dialogs.c 11132 2010-08-06 14:38:54Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -64,20 +64,7 @@ quitresp( GtkWidget * widget,
     gtk_widget_destroy( widget );
 }
 
-static gboolean
-countActiveTorrents( GtkTreeModel *       model,
-                     GtkTreePath   * path UNUSED,
-                     GtkTreeIter *        iter,
-                     gpointer             activeTorrentCount )
-{
-    int activity = -1;
-    gtk_tree_model_get( model, iter, MC_ACTIVITY, &activity, -1 );
-    if( activity != TR_STATUS_STOPPED )
-        *(int*)activeTorrentCount += 1;
-    return FALSE; /* keep iterating */
-}
-
-void
+GtkWidget *
 askquit( TrCore *       core,
          GtkWindow *    parent,
          callbackfunc_t func,
@@ -87,25 +74,6 @@ askquit( TrCore *       core,
     GtkWidget *       w;
     GtkWidget *       wind;
     GtkWidget *       dontask;
-    GtkTreeModel *    model;
-    int               activeTorrentCount;
-
-    /* if the user doesn't want to be asked, don't ask */
-    if( !pref_flag_get( PREF_KEY_ASKQUIT ) )
-    {
-        func( cbdata );
-        return;
-    }
-
-    /* if there aren't any active torrents, don't ask */
-    model = tr_core_model( core );
-    activeTorrentCount = 0;
-    gtk_tree_model_foreach( model, countActiveTorrents, &activeTorrentCount );
-    if( !activeTorrentCount )
-    {
-        func( cbdata );
-        return;
-    }
 
     stuff          = g_new( struct quitdata, 1 );
     stuff->func    = func;
@@ -142,6 +110,8 @@ askquit( TrCore *       core,
     gtk_widget_grab_focus( w );
 
     gtk_widget_show_all( wind );
+
+    return wind;
 }
 
 /***
@@ -175,8 +145,6 @@ removeResponse( GtkDialog * dialog,
 
     if( response == GTK_RESPONSE_ACCEPT )
         removeTorrents( data );
-    else
-        g_slist_foreach( data->torrents, (GFunc)g_object_unref, NULL );
 
     gtk_widget_destroy( GTK_WIDGET( dialog ) );
     g_slist_free( data->torrents );
@@ -208,7 +176,7 @@ confirmRemove( GtkWindow * parent,
     GtkWidget *         d;
     const int           count = g_slist_length( torrents );
     struct count_data   counts;
-    const char        * primary_text;
+    GString           * primary_text;
     GString           * secondary_text;
     struct DeleteData * dd;
 
@@ -224,65 +192,63 @@ confirmRemove( GtkWindow * parent,
     counts.connected = 0;
     g_slist_foreach( torrents, countBusyTorrents, &counts );
 
-    if( !counts.incomplete && !counts.connected && !delete_files ) /* don't prompt boring torrents */
-    {
-        removeTorrents( dd );
-        g_free( dd );
-        return;
-    }
+    primary_text = g_string_new( NULL );
 
     if( !delete_files )
     {
-        primary_text = ngettext( "Remove torrent?",
-                                 "Remove torrents?",
-                                 count );
+        g_string_printf( primary_text, gtr_ngettext( "Remove torrent?",
+                                                     "Remove %d torrents?",
+                                                     count ), count );
     }
     else
     {
-        primary_text = ngettext( "Delete this torrent's downloaded files?",
-                                 "Delete these torrents' downloaded files?",
-                                 count );
+        g_string_printf( primary_text, gtr_ngettext( "Delete this torrent's downloaded files?",
+                                                     "Delete these %d torrents' downloaded files?",
+                                                     count ), count );
     }
 
     secondary_text = g_string_new( NULL );
 
     if( !counts.incomplete && !counts.connected )
     {
-        /* boring -- no secondary text needed */
+        g_string_assign( secondary_text, gtr_ngettext(
+                "Once removed, continuing the transfer will require the torrent file or magnet link.",
+                "Once removed, continuing the transfers will require the torrent files or magnet links.",
+                count ) );
     }
     else if( count == counts.incomplete )
     {
-        g_string_assign( secondary_text, ngettext( "This torrent has not finished downloading.",
-                                                   "These torrents have not finished downloading.",
-                                                   count ) );
+        g_string_assign( secondary_text, gtr_ngettext( "This torrent has not finished downloading.",
+                                                       "These torrents have not finished downloading.",
+                                                       count ) );
     }
     else if( count == counts.connected )
     {
-        g_string_assign( secondary_text, ngettext( "This torrent is connected to peers.",
-                                                   "These torrents are connected to peers.",
-                                                   count ) );
+        g_string_assign( secondary_text, gtr_ngettext( "This torrent is connected to peers.",
+                                                       "These torrents are connected to peers.",
+                                                       count ) );
     }
     else
     {
         if( counts.connected )
-            g_string_append( secondary_text, ngettext( "One of these torrents is connected to peers.",
-                                                       "Some of these torrents are connected to peers.",
+            g_string_append( secondary_text, gtr_ngettext( "One of these torrents is connected to peers.",
+                                                           "Some of these torrents are connected to peers.",
                                                        counts.connected ) );
         if( counts.connected && counts.incomplete )
             g_string_append( secondary_text, "\n" );
- 
+
         if( counts.incomplete )
-            g_string_assign( secondary_text, ngettext( "One of these torrents has not finished downloading.",
-                                                       "Some of these torrents have not finished downloading.",
+            g_string_assign( secondary_text, gtr_ngettext( "One of these torrents has not finished downloading.",
+                                                           "Some of these torrents have not finished downloading.",
                                                        counts.incomplete ) );
     }
 
     d = gtk_message_dialog_new_with_markup( parent,
                                             GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_WARNING,
+                                            GTK_MESSAGE_QUESTION,
                                             GTK_BUTTONS_NONE,
                                             "<big><b>%s</b></big>",
-                                            primary_text );
+                                            primary_text->str );
     if( secondary_text->len )
         gtk_message_dialog_format_secondary_markup( GTK_MESSAGE_DIALOG( d ),
                                                     "%s", secondary_text->str );
@@ -300,5 +266,6 @@ confirmRemove( GtkWindow * parent,
     g_signal_connect( d, "response", G_CALLBACK( removeResponse ), dd );
     gtk_widget_show_all( d );
 
+    g_string_free( primary_text, TRUE );
     g_string_free( secondary_text, TRUE );
 }
