@@ -1,5 +1,5 @@
 /*
- * This file Copyright (C) 2007-2008 Charles Kerr <charles@rebelbase.com>
+ * This file Copyright (C) 2007-2010 Mnemosyne LLC
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: hig.h 6998 2008-10-31 18:25:21Z charles $
+ * $Id: hig.h 9868 2010-01-04 21:00:47Z charles $
  */
 
 #ifndef __HIG_H__
@@ -33,6 +33,10 @@ void       hig_workarea_add_section_title( GtkWidget *  table,
                                            int *        row,
                                            const char * section_title );
 
+void       hig_workarea_add_wide_tall_control( GtkWidget * table,
+                                               int *       row,
+                                               GtkWidget * w );
+
 void       hig_workarea_add_wide_control( GtkWidget * table,
                                           int *       row,
                                           GtkWidget * w );
@@ -54,6 +58,12 @@ void       hig_workarea_add_control( GtkWidget * table,
                                      int         row,
                                      GtkWidget * control );
 
+GtkWidget* hig_workarea_add_tall_row( GtkWidget *  table,
+                                      int *        row,
+                                      const char * mnemonic_string,
+                                      GtkWidget *  control,
+                                      GtkWidget *  mnemonic_or_null_for_control );
+
 GtkWidget* hig_workarea_add_row( GtkWidget *  table,
                                  int *        row,
                                  const char * mnemonic_string,
