@@ -7,14 +7,12 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: msgwin.h 9868 2010-01-04 21:00:47Z charles $
+ * $Id: msgwin.h 11337 2010-10-18 22:18:15Z charles $
  */
 
 #ifndef TG_MSGWIN_H
 #define TG_MSGWIN_H
 
-struct TrCore;
-
-GtkWidget * msgwin_new( struct TrCore * core );
+GtkWidget * msgwin_new( TrCore * core, GtkWindow * parent );
 
 #endif
