@@ -7,15 +7,17 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id:$
+ * $Id: relocate.h 11280 2010-10-01 13:33:39Z charles $
  */
 
 #ifndef GTR_RELOCATE_H
 #define GTR_RELOCATE_H
 
 #include <gtk/gtk.h>
-#include <libtransmission/transmission.h>
+#include "tr-core.h"
 
-GtkWidget * gtr_relocate_dialog_new( GtkWindow * parent, tr_torrent * tor );
+GtkWidget * gtr_relocate_dialog_new( GtkWindow * parent,
+                                     TrCore    * core,
+                                     GSList    * torrentIds );
 
 #endif
