@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: tr-core.h 10717 2010-06-03 19:53:01Z charles $
+ * $Id: tr-core.h 11114 2010-08-04 17:35:48Z Longinus00 $
  *
  * Copyright (c) 2007-2008 Transmission authors and contributors
  *
@@ -43,44 +43,14 @@
                                                          TR_CORE_TYPE, \
                                                          TrCoreClass )
 
-typedef struct TrCore
+typedef struct _TrCore
 {
-    GObject    parent;
+    GObject parent;
+
     struct TrCorePrivate  * priv;
 }
 TrCore;
 
-typedef struct TrCoreClass
-{
-    GObjectClass    parent;
-
-    /* "blocklist-updated" signal with a callback type of
-        void (*callback )( TrCore*, int ruleCount, gpointer userData ). */
-    int blocklistSignal;
-
-    /* "port-tested" signal with a callback type of
-       void( *callback )( TrCore*, gboolean isOpen, gpointer userData ). */
-    int portSignal;
-
-    /* "error" signal with a callback type of
-       void( *callback )( TrCore*, enum tr_core_err, const char * humanReadable, gpointer userData ). */
-    int errsig;
-
-    /* "add-torrent-prompt" signal with a callback type of
-       void ( *callback)( TrCore *, gpointer ctor, gpointer userData )
-       The handler assumes ownership of ctor and must free when done */
-    int promptsig;
-
-    /* "quit" signal:
-       void handler( TrCore *, gpointer ) */
-    int quitsig;
-
-    /* "prefs-changed" signal:
-       void handler( TrCore *, int, gpointer ) */
-    int prefsig;
-}
-TrCoreClass;
-
 enum tr_core_err
 {
     TR_CORE_ERR_ADD_TORRENT_ERR  = TR_PARSE_ERR,
@@ -88,6 +58,20 @@ enum tr_core_err
     TR_CORE_ERR_NO_MORE_TORRENTS = 1000 /* finished adding a batch */
 };
 
+typedef struct _TrCoreClass
+{
+    GObjectClass parent_class;
+
+    void (* add_error)         (TrCore*, enum tr_core_err, const char * name);
+    void (* add_prompt)        (TrCore*, gpointer ctor);
+    void (* blocklist_updated) (TrCore*, int ruleCount );
+    void (* busy)              (TrCore*, gboolean isBusy);
+    void (* prefs_changed)     (TrCore*, const char* key);
+    void (* port_tested)       (TrCore*, gboolean isOpen);
+    void (* quit)              (TrCore*);
+}
+TrCoreClass;
+
 GType          tr_core_get_type( void );
 
 TrCore *       tr_core_new( tr_session * );
@@ -133,8 +117,7 @@ void     tr_core_add_list( TrCore *    self,
 
 /** @brief Add a torrent. */
 gboolean tr_core_add_metainfo( TrCore      * core,
-                               const char  * payload,
-                               const char  * optional_filename,
+                               const char  * base64_metainfo,
                                gboolean    * setme_success,
                                GError     ** err );
 
@@ -212,7 +195,11 @@ enum
     MC_TORRENT_RAW,
     MC_SPEED_UP,
     MC_SPEED_DOWN,
+    MC_ACTIVE,
     MC_ACTIVITY,
+    MC_FINISHED,
+    MC_PRIORITY,
+    MC_TRACKERS,
     MC_ROW_COUNT
 };
 
