@@ -1,5 +1,5 @@
 /*
- * This file Copyright (C) 2008-2009 Charles Kerr <charles@transmissionbt.com>
+ * This file Copyright (C) 2008-2010 Mnemosyne LLC
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
@@ -7,14 +7,12 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: bandwidth.c 7813 2009-01-29 18:18:24Z charles $
+ * $Id: bandwidth.c 11349 2010-10-24 01:08:08Z charles $
  */
 
 #include <assert.h>
 #include <limits.h>
 
-#include "event.h"
-
 #include "transmission.h"
 #include "bandwidth.h"
 #include "crypto.h"
@@ -32,11 +30,11 @@
 ****
 ***/
 
-static float
-getSpeed( const struct bratecontrol * r, int interval_msec, uint64_t now )
+static unsigned int
+getSpeed_Bps( const struct bratecontrol * r, unsigned int interval_msec, uint64_t now )
 {
     uint64_t       bytes = 0;
-    const uint64_t cutoff = (now?now:tr_date()) - interval_msec;
+    const uint64_t cutoff = (now?now:tr_time_msec()) - interval_msec;
     int            i = r->newest;
 
     for( ;; )
@@ -50,7 +48,7 @@ getSpeed( const struct bratecontrol * r, int interval_msec, uint64_t now )
         if( i == r->newest ) break; /* we've come all the way around */
     }
 
-    return ( bytes / 1024.0 ) * ( 1000.0 / interval_msec );
+    return (unsigned int)(( bytes * 1000u ) / interval_msec);
 }
 
 static void
@@ -71,7 +69,7 @@ bytesUsed( const uint64_t now, struct bratecontrol * r, size_t size )
 *******
 ******/
 
-static TR_INLINE int
+static inline int
 comparePointers( const void * a, const void * b )
 {
     if( a != b )
@@ -121,9 +119,14 @@ tr_bandwidthSetParent( tr_bandwidth  * b,
 
     if( b->parent )
     {
+        void * removed;
+
         assert( tr_isBandwidth( b->parent ) );
 
-        tr_ptrArrayRemoveSorted( &b->parent->children, b, comparePointers );
+        removed = tr_ptrArrayRemoveSorted( &b->parent->children, b, comparePointers );
+        assert( removed == b );
+        assert( tr_ptrArrayFindSorted( &b->parent->children, b, comparePointers ) == NULL );
+
         b->parent = NULL;
     }
 
@@ -133,6 +136,7 @@ tr_bandwidthSetParent( tr_bandwidth  * b,
         assert( parent->parent != b );
 
         tr_ptrArrayInsertSorted( &parent->children, b, comparePointers );
+        assert( tr_ptrArrayFindSorted( &parent->children, b, comparePointers ) == b );
         b->parent = parent;
     }
 }
@@ -140,7 +144,6 @@ tr_bandwidthSetParent( tr_bandwidth  * b,
 /***
 ****
 ***/
-
 #if 0
 #warning do not check the code in with this enabled
 #define DEBUG_DIRECTION TR_UP
@@ -148,31 +151,37 @@ tr_bandwidthSetParent( tr_bandwidth  * b,
 
 static void
 allocateBandwidth( tr_bandwidth  * b,
+                   tr_priority_t   parent_priority,
                    tr_direction    dir,
-                   int             period_msec,
+                   unsigned int    period_msec,
                    tr_ptrArray   * peer_pool )
 {
+    tr_priority_t priority;
+
     assert( tr_isBandwidth( b ) );
     assert( tr_isDirection( dir ) );
 
     /* set the available bandwidth */
     if( b->band[dir].isLimited )
     {
-        const double desiredSpeed = b->band[dir].desiredSpeed;
-        const double nextPulseSpeed = desiredSpeed;
-        b->band[dir].bytesLeft = MAX( 0.0, nextPulseSpeed * 1024.0 * period_msec / 1000.0 );
+        const unsigned int nextPulseSpeed = b->band[dir].desiredSpeed_Bps;
+        b->band[dir].bytesLeft = ( nextPulseSpeed * period_msec ) / 1000u;
 
 #ifdef DEBUG_DIRECTION
         if( dir == DEBUG_DIRECTION )
-                fprintf( stderr, "bandwidth %p currentPieceSpeed(%5.2f of %5.2f) desiredSpeed(%5.2f), allocating %5.2f\n",
+                fprintf( stderr, "bandwidth %p currentPieceSpeed(%5.2f of %5.2f) desiredSpeed(%5.2f), allocating %d\n",
                          b, currentSpeed, tr_bandwidthGetRawSpeed( b, dir ), desiredSpeed,
-                         b->band[dir].bytesLeft/1024.0 );
+                         b->band[dir].bytesLeft );
 #endif
     }
 
+    priority = MAX( parent_priority, b->priority );
+
     /* add this bandwidth's peer, if any, to the peer pool */
-    if( b->peer != NULL )
+    if( b->peer != NULL ) {
+        b->peer->priority = priority;
         tr_ptrArrayAppend( peer_pool, b->peer );
+    }
 
 #ifdef DEBUG_DIRECTION
 if( ( dir == DEBUG_DIRECTION ) && ( n > 1 ) )
@@ -185,28 +194,16 @@ fprintf( stderr, "bandwidth %p has %d peers\n", b, n );
         struct tr_bandwidth ** children = (struct tr_bandwidth**) tr_ptrArrayBase( &b->children );
         const int n = tr_ptrArraySize( &b->children );
         for( i=0; i<n; ++i )
-            allocateBandwidth( children[i], dir, period_msec, peer_pool );
+            allocateBandwidth( children[i], priority, dir, period_msec, peer_pool );
     }
 }
 
-void
-tr_bandwidthAllocate( tr_bandwidth  * b,
-                      tr_direction    dir,
-                      int             period_msec )
+static void
+phaseOne( tr_ptrArray * peerArray, tr_direction dir )
 {
-    int i, n, peerCount;
-    tr_ptrArray tmp = TR_PTR_ARRAY_INIT;
-    struct tr_peerIo ** peers;
-
-    /* allocateBandwidth() is a helper function with two purposes:
-     * 1. allocate bandwidth to b and its subtree
-     * 2. accumulate an array of all the peerIos from b and its subtree. */
-    allocateBandwidth( b, dir, period_msec, &tmp );
-    peers = (struct tr_peerIo**) tr_ptrArrayBase( &tmp );
-    peerCount = tr_ptrArraySize( &tmp );
-
-    for( i=0; i<peerCount; ++i )
-        tr_peerIoRef( peers[i] );
+    int i, n;
+    int peerCount = tr_ptrArraySize( peerArray );
+    struct tr_peerIo ** peers = (struct tr_peerIo**) tr_ptrArrayBase( peerArray );
 
     /* First phase of IO.  Tries to distribute bandwidth fairly to keep faster
      * peers from starving the others.  Loop through the peers, giving each a
@@ -235,6 +232,48 @@ tr_bandwidthAllocate( tr_bandwidth  * b,
         if( i == n )
             i = 0;
     }
+}
+
+void
+tr_bandwidthAllocate( tr_bandwidth  * b,
+                      tr_direction    dir,
+                      unsigned int    period_msec )
+{
+    int i, peerCount;
+    tr_ptrArray tmp = TR_PTR_ARRAY_INIT;
+    tr_ptrArray low = TR_PTR_ARRAY_INIT;
+    tr_ptrArray high = TR_PTR_ARRAY_INIT;
+    tr_ptrArray normal = TR_PTR_ARRAY_INIT;
+    struct tr_peerIo ** peers;
+
+    /* allocateBandwidth() is a helper function with two purposes:
+     * 1. allocate bandwidth to b and its subtree
+     * 2. accumulate an array of all the peerIos from b and its subtree. */
+    allocateBandwidth( b, TR_PRI_LOW, dir, period_msec, &tmp );
+    peers = (struct tr_peerIo**) tr_ptrArrayBase( &tmp );
+    peerCount = tr_ptrArraySize( &tmp );
+
+    for( i=0; i<peerCount; ++i )
+    {
+        tr_peerIo * io = peers[i];
+        tr_peerIoRef( io );
+
+        tr_peerIoFlushOutgoingProtocolMsgs( io );
+
+        switch( io->priority ) {
+            case TR_PRI_HIGH:   tr_ptrArrayAppend( &high,   io ); /* fall through */
+            case TR_PRI_NORMAL: tr_ptrArrayAppend( &normal, io ); /* fall through */
+            default:            tr_ptrArrayAppend( &low,    io );
+        }
+    }
+
+    /* First phase of IO.  Tries to distribute bandwidth fairly to keep faster
+     * peers from starving the others.  Loop through the peers, giving each a
+     * small chunk of bandwidth.  Keep looping until we run out of bandwidth
+     * and/or peers that can use it */
+    phaseOne( &high, dir );
+    phaseOne( &normal, dir );
+    phaseOne( &low, dir );
 
     /* Second phase of IO.  To help us scale in high bandwidth situations,
      * enable on-demand IO for peers with bandwidth left to burn.
@@ -247,6 +286,9 @@ tr_bandwidthAllocate( tr_bandwidth  * b,
         tr_peerIoUnref( peers[i] );
 
     /* cleanup */
+    tr_ptrArrayDestruct( &normal, NULL );
+    tr_ptrArrayDestruct( &high, NULL );
+    tr_ptrArrayDestruct( &low, NULL );
     tr_ptrArrayDestruct( &tmp, NULL );
 }
 
@@ -263,10 +305,10 @@ tr_bandwidthSetPeer( tr_bandwidth * b, tr_peerIo * peer )
 ****
 ***/
 
-size_t
+unsigned int
 tr_bandwidthClamp( const tr_bandwidth  * b,
                    tr_direction          dir,
-                   size_t                byteCount )
+                   unsigned int          byteCount )
 {
     assert( tr_isBandwidth( b ) );
     assert( tr_isDirection( dir ) );
@@ -283,41 +325,38 @@ tr_bandwidthClamp( const tr_bandwidth  * b,
     return byteCount;
 }
 
-double
-tr_bandwidthGetRawSpeed( const tr_bandwidth * b, const uint64_t now, const tr_direction dir )
+unsigned int
+tr_bandwidthGetRawSpeed_Bps( const tr_bandwidth * b, const uint64_t now, const tr_direction dir )
 {
     assert( tr_isBandwidth( b ) );
     assert( tr_isDirection( dir ) );
 
-    return getSpeed( &b->band[dir].raw, HISTORY_MSEC, now );
+    return getSpeed_Bps( &b->band[dir].raw, HISTORY_MSEC, now );
 }
 
-double
-tr_bandwidthGetPieceSpeed( const tr_bandwidth * b, const uint64_t now, const tr_direction dir )
+unsigned int
+tr_bandwidthGetPieceSpeed_Bps( const tr_bandwidth * b, const uint64_t now, const tr_direction dir )
 {
     assert( tr_isBandwidth( b ) );
     assert( tr_isDirection( dir ) );
 
-    return getSpeed( &b->band[dir].piece, HISTORY_MSEC, now );
+    return getSpeed_Bps( &b->band[dir].piece, HISTORY_MSEC, now );
 }
 
-static void
-bandwidthUsedImpl( tr_bandwidth  * b,
-                   tr_direction    dir,
-                   size_t          byteCount,
-                   tr_bool         isPieceData,
-                   uint64_t        now )
+void
+tr_bandwidthUsed( tr_bandwidth  * b,
+                  tr_direction    dir,
+                  size_t          byteCount,
+                  tr_bool         isPieceData,
+                  uint64_t        now )
 {
     struct tr_band * band;
-    size_t oldBytesLeft;
 
     assert( tr_isBandwidth( b ) );
     assert( tr_isDirection( dir ) );
 
     band = &b->band[dir];
 
-    oldBytesLeft = band->bytesLeft;
-
     if( band->isLimited && isPieceData )
         band->bytesLeft -= MIN( band->bytesLeft, byteCount );
 
@@ -333,14 +372,5 @@ fprintf( stderr, "%p consumed %5zu bytes of %5s data... was %6zu, now %6zu left\
         bytesUsed( now, &band->piece, byteCount );
 
     if( b->parent != NULL )
-        bandwidthUsedImpl( b->parent, dir, byteCount, isPieceData, now );
-}
-
-void
-tr_bandwidthUsed( tr_bandwidth  * b,
-                  tr_direction    dir,
-                  size_t          byteCount,
-                  tr_bool         isPieceData )
-{
-    bandwidthUsedImpl( b, dir, byteCount, isPieceData, tr_date( ) );
+        tr_bandwidthUsed( b->parent, dir, byteCount, isPieceData, now );
 }
