@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: bencode.c 11356 2010-10-26 19:30:35Z charles $
+ * $Id: bencode.c 11445 2010-12-01 04:54:18Z charles $
  */
 
 #include <assert.h>
@@ -1667,7 +1667,6 @@ tr_bencToFile( const tr_benc * top, tr_fmt_mode mode, const char * filename )
     {
         int len;
         char * str = tr_bencToStr( top, mode, &len );
-        tr_dbg( "Writing %d bytes to temporary file \"%s\"", (int)len, tmp );
 
         if( write( fd, str, len ) == (ssize_t)len )
         {
@@ -1679,8 +1678,6 @@ tr_bencToFile( const tr_benc * top, tr_fmt_mode mode, const char * filename )
 
             if( !already_exists || !unlink( filename ) )
             {
-                tr_dbg( "Renaming \"%s\" as \"%s\"", tmp, filename );
-
                 if( !rename( tmp, filename ) )
                 {
                     tr_inf( _( "Saved \"%s\"" ), filename );
