@@ -45,6 +45,10 @@ main( void )
     TEST_CLIENT( "-TR111Z-", "Transmission 1.11+" );
     TEST_CLIENT( "O1008132", "Osprey 1.0.0" );
 
+    /* gobbledygook */
+    TEST_CLIENT( "-IIO\x10\x2D\x04-", "-IIO%10-%04-" );
+    TEST_CLIENT( "-I\05O\x08\x03\x01-", "-I%05O%08%03%01-" );
+
     TEST_CLIENT(
         "\x65\x78\x62\x63\x00\x38\x7A\x44\x63\x10\x2D\x6E\x9A\xD6\x72\x3B\x33\x9F\x35\xA9",
         "BitComet 0.56" );
