@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: completion.c 9868 2010-01-04 21:00:47Z charles $
+ * $Id: completion.c 10912 2010-06-30 16:40:19Z charles $
  */
 
 #include <assert.h>
@@ -164,11 +164,29 @@ tr_cpBlockAdd( tr_completion * cp, tr_block_index_t block )
     }
 }
 
+
+void
+tr_cpSetHaveAll( tr_completion * cp )
+{
+    tr_piece_index_t i;
+    tr_torrent * tor = cp->tor;
+
+    tr_cpReset( cp );
+
+    cp->sizeNow = tor->info.totalSize;
+    tr_bitfieldAddRange( &cp->blockBitfield, 0, tor->blockCount );
+    tr_bitfieldAddRange( &cp->pieceBitfield, 0, tor->info.pieceCount );
+    for( i=0; i<tor->info.pieceCount; ++i )
+        cp->completeBlocks[i] = tr_torPieceCountBlocks( tor, i );
+    cp->sizeWhenDoneIsDirty = 1;
+    cp->haveValidIsDirty = 1;
+}
+
 /* Initialize a completion object from a bitfield indicating which blocks we have */
 tr_bool
 tr_cpBlockBitfieldSet( tr_completion * cp, tr_bitfield * blockBitfield )
 {
-    int success = FALSE;
+    tr_bool success = FALSE;
 
     assert( cp );
     assert( blockBitfield );
@@ -180,7 +198,7 @@ tr_cpBlockBitfieldSet( tr_completion * cp, tr_bitfield * blockBitfield )
         tr_block_index_t b = 0;
         tr_piece_index_t p = 0;
         uint32_t pieceBlock = 0;
-        uint32_t completeBlocksInPiece = 0;
+        uint16_t completeBlocksInPiece = 0;
         tr_block_index_t completeBlocksInTorrent = 0;
         uint32_t blocksInCurrentPiece = tr_torPieceCountBlocks( cp->tor, p );
 
