@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: makemeta.c 11334 2010-10-17 22:28:28Z charles $
+ * $Id: makemeta.c 11490 2010-12-08 14:57:34Z charles $
  */
 
 #include <assert.h>
@@ -310,7 +310,7 @@ getFileInfo( const char *                     topFile,
         char * filename = tr_strdup( file->filename + offset );
         char * walk = filename;
         const char * token;
-        while(( token = strsep( &walk, TR_PATH_DELIMITER_STR )))
+        while(( token = tr_strsep( &walk, TR_PATH_DELIMITER_STR )))
             tr_bencListAddStr( uninitialized_path, token );
         tr_free( filename );
     }
