@@ -1,5 +1,5 @@
 /*
- * This file Copyright (C) 2007-2009 Charles Kerr <charles@transmissionbt.com>
+ * This file Copyright (C) 2007-2010 Mnemosyne LLC
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: natpmp.h 8561 2009-05-29 19:17:12Z charles $
+ * $Id: natpmp.h 10945 2010-07-05 21:04:17Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -17,7 +17,7 @@
 #ifndef TR_NATPMP_H
 #define TR_NATPMP_H 1
 
-/** 
+/**
  * @addtogroup port_forwarding Port Forwarding
  * @{
  */
@@ -26,11 +26,9 @@ typedef struct tr_natpmp tr_natpmp;
 
 tr_natpmp * tr_natpmpInit( void );
 
-void        tr_natpmpClose( tr_natpmp * );
+void tr_natpmpClose( tr_natpmp * );
 
-int         tr_natpmpPulse(         tr_natpmp *,
-                                int port,
-                                int isEnabled );
+int tr_natpmpPulse( tr_natpmp *, tr_port port, tr_bool isEnabled, tr_port * public_port );
 
 /* @} */
 #endif
