@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: net.c 11311 2010-10-14 17:03:04Z charles $
+ * $Id: net.c 11494 2010-12-08 17:22:00Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -338,7 +338,7 @@ tr_netOpenPeerSocket( tr_session        * session,
         if( ( tmperrno != ENETUNREACH && tmperrno != EHOSTUNREACH )
                 || addr->type == TR_AF_INET )
             tr_err( _( "Couldn't connect socket %d to %s, port %d (errno %d - %s)" ),
-                    s, tr_ntop_non_ts( addr ), (int)port, tmperrno,
+                    s, tr_ntop_non_ts( addr ), (int)ntohs( port ), tmperrno,
                     tr_strerror( tmperrno ) );
         tr_netClose( session, s );
         s = -tmperrno;
