@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-io.c 10603 2010-05-01 14:53:37Z charles $
+ * $Id: peer-io.c 11398 2010-11-11 15:31:11Z charles $
  */
 
 #include <assert.h>
@@ -31,12 +31,20 @@
 #include "crypto.h"
 #include "list.h"
 #include "net.h"
+#include "peer-common.h" /* MAX_BLOCK_SIZE */
 #include "peer-io.h"
 #include "trevent.h" /* tr_runInEventThread() */
 #include "utils.h"
 
 #define MAGIC_NUMBER 206745
 
+#ifdef WIN32
+ #define EAGAIN       WSAEWOULDBLOCK
+ #define EINTR        WSAEINTR
+ #define EINPROGRESS  WSAEINPROGRESS
+ #define EPIPE        WSAECONNRESET
+#endif
+
 static size_t
 guessPacketOverhead( size_t d )
 {
@@ -58,7 +66,7 @@ guessPacketOverhead( size_t d )
      */
     const double assumed_payload_data_rate = 94.0;
 
-    return (size_t)( d * ( 100.0 / assumed_payload_data_rate ) - d );
+    return (unsigned int)( d * ( 100.0 / assumed_payload_data_rate ) - d );
 }
 
 /**
@@ -82,19 +90,20 @@ struct tr_datatype
 ***/
 
 static void
-didWriteWrapper( tr_peerIo * io, size_t bytes_transferred )
+didWriteWrapper( tr_peerIo * io, unsigned int bytes_transferred )
 {
      while( bytes_transferred && tr_isPeerIo( io ) )
      {
         struct tr_datatype * next = io->outbuf_datatypes->data;
 
-        const size_t payload = MIN( next->length, bytes_transferred );
-        const size_t overhead = guessPacketOverhead( payload );
+        const unsigned int payload = MIN( next->length, bytes_transferred );
+        const unsigned int overhead = guessPacketOverhead( payload );
+        const uint64_t now = tr_time_msec( );
 
-        tr_bandwidthUsed( &io->bandwidth, TR_UP, payload, next->isPieceData );
+        tr_bandwidthUsed( &io->bandwidth, TR_UP, payload, next->isPieceData, now );
 
         if( overhead > 0 )
-            tr_bandwidthUsed( &io->bandwidth, TR_UP, overhead, FALSE );
+            tr_bandwidthUsed( &io->bandwidth, TR_UP, overhead, FALSE, now );
 
         if( io->didWrite )
             io->didWrite( io, payload, next->isPieceData, io->userData );
@@ -141,11 +150,16 @@ canReadWrapper( tr_peerIo * io )
 
             assert( tr_isPeerIo( io ) );
 
-            if( piece )
-                tr_bandwidthUsed( &io->bandwidth, TR_DOWN, piece, TRUE );
+            if( piece || (piece!=used) )
+            {
+                const uint64_t now = tr_time_msec( );
 
-            if( used != piece )
-                tr_bandwidthUsed( &io->bandwidth, TR_DOWN, used - piece, FALSE );
+                if( piece )
+                    tr_bandwidthUsed( &io->bandwidth, TR_DOWN, piece, TRUE, now );
+
+                if( used != piece )
+                    tr_bandwidthUsed( &io->bandwidth, TR_DOWN, used - piece, FALSE, now );
+            }
 
             switch( ret )
             {
@@ -198,10 +212,10 @@ event_read_cb( int fd, short event UNUSED, void * vio )
     tr_peerIo * io = vio;
 
     /* Limit the input buffer to 256K, so it doesn't grow too large */
-    size_t howmuch;
+    unsigned int howmuch;
+    unsigned int curlen;
     const tr_direction dir = TR_DOWN;
-    const size_t max = 256 * 1024;
-    size_t curlen;
+    const unsigned int max = 256 * 1024;
 
     assert( tr_isPeerIo( io ) );
 
@@ -220,9 +234,9 @@ event_read_cb( int fd, short event UNUSED, void * vio )
         return;
     }
 
-    errno = 0;
-    res = evbuffer_read( io->inbuf, fd, howmuch );
-    e = errno;
+    EVUTIL_SET_SOCKET_ERROR( 0 );
+    res = evbuffer_read( io->inbuf, fd, (int)howmuch );
+    e = EVUTIL_SOCKET_ERROR( );
 
     if( res > 0 )
     {
@@ -233,6 +247,7 @@ event_read_cb( int fd, short event UNUSED, void * vio )
     }
     else
     {
+        char errstr[512];
         short what = EVBUFFER_READ;
 
         if( res == 0 ) /* EOF */
@@ -245,7 +260,8 @@ event_read_cb( int fd, short event UNUSED, void * vio )
             what |= EVBUFFER_ERROR;
         }
 
-        dbgmsg( io, "event_read_cb got an error. res is %d, what is %hd, errno is %d (%s)", res, what, e, strerror( e ) );
+        tr_net_strerror( errstr, sizeof( errstr ), e );
+        dbgmsg( io, "event_read_cb got an error. res is %d, what is %hd, errno is %d (%s)", res, what, e, errstr );
 
         if( io->gotError != NULL )
             io->gotError( io, what, io->userData );
@@ -257,21 +273,22 @@ tr_evbuffer_write( tr_peerIo * io, int fd, size_t howmuch )
 {
     int e;
     int n;
+    char errstr[256];
     struct evbuffer * buffer = io->outbuf;
 
     howmuch = MIN( EVBUFFER_LENGTH( buffer ), howmuch );
 
-    errno = 0;
+    EVUTIL_SET_SOCKET_ERROR( 0 );
 #ifdef WIN32
     n = (int) send(fd, buffer->buffer, howmuch,  0 );
 #else
     n = (int) write(fd, buffer->buffer, howmuch );
 #endif
-    e = errno;
-    dbgmsg( io, "wrote %d to peer (%s)", n, (n==-1?strerror(e):"") );
+    e = EVUTIL_SOCKET_ERROR( );
+    dbgmsg( io, "wrote %d to peer (%s)", n, (n==-1?tr_net_strerror(errstr,sizeof(errstr),e):"") );
 
     if( n > 0 )
-        evbuffer_drain( buffer, n );
+        evbuffer_drain( buffer, (size_t)n );
 
     /* keep the iobuf's excess capacity from growing too large */
     if( EVBUFFER_LENGTH( io->outbuf ) == 0 ) {
@@ -309,23 +326,15 @@ event_write_cb( int fd, short event UNUSED, void * vio )
         return;
     }
 
-    errno = 0;
+    EVUTIL_SET_SOCKET_ERROR( 0 );
     res = tr_evbuffer_write( io, fd, howmuch );
-    e = errno;
+    e = EVUTIL_SOCKET_ERROR( );
 
     if (res == -1) {
-#ifndef WIN32
-/*todo. evbuffer uses WriteFile when WIN32 is set. WIN32 system calls do not
- *  *set errno. thus this error checking is not portable*/
         if (e == EAGAIN || e == EINTR || e == EINPROGRESS)
             goto reschedule;
         /* error case */
         what |= EVBUFFER_ERROR;
-
-#else
-        goto reschedule;
-#endif
-
     } else if (res == 0) {
         /* eof case */
         what |= EVBUFFER_EOF;
@@ -356,6 +365,19 @@ event_write_cb( int fd, short event UNUSED, void * vio )
 ***
 **/
 
+static void
+maybeSetCongestionAlgorithm( int socket, const char * algorithm )
+{
+    if( algorithm && *algorithm )
+    {
+        const int rc = tr_netSetCongestionControl( socket, algorithm );
+
+        if( rc < 0 )
+            tr_ninf( "Net", "Can't set congestion control algorithm '%s': %s",
+                     algorithm, tr_strerror( errno ));
+    }
+}
+
 static tr_peerIo*
 tr_peerIoNew( tr_session       * session,
               tr_bandwidth     * parent,
@@ -374,8 +396,10 @@ tr_peerIoNew( tr_session       * session,
     assert( tr_isBool( isSeed ) );
     assert( tr_amInEventThread( session ) );
 
-    if( socket >= 0 )
+    if( socket >= 0 ) {
         tr_netSetTOS( socket, session->peerSocketTOS );
+        maybeSetCongestionAlgorithm( socket, session->peer_congestion_algorithm );
+    }
 
     io = tr_new0( tr_peerIo, 1 );
     io->magicNumber = MAGIC_NUMBER;
@@ -594,6 +618,11 @@ tr_peerIoAddrStr( const tr_address * addr, tr_port port )
     return buf;
 }
 
+const char* tr_peerIoGetAddrStr( const tr_peerIo * io )
+{
+    return tr_isPeerIo( io ) ? tr_peerIoAddrStr( &io->addr, io->port ) : "error";
+}
+
 void
 tr_peerIoSetIOFuncs( tr_peerIo        * io,
                      tr_can_read_cb     readcb,
@@ -618,7 +647,7 @@ tr_peerIoClear( tr_peerIo * io )
 int
 tr_peerIoReconnect( tr_peerIo * io )
 {
-    int pendingEvents;
+    short int pendingEvents;
     tr_session * session;
 
     assert( tr_isPeerIo( io ) );
@@ -640,6 +669,7 @@ tr_peerIoReconnect( tr_peerIo * io )
     {
         event_enable( io, pendingEvents );
         tr_netSetTOS( io->socket, session->peerSocketTOS );
+        maybeSetCongestionAlgorithm( io->socket, session->peer_congestion_algorithm );
         return 0;
     }
 
@@ -697,54 +727,18 @@ tr_peerIoSetPeersId( tr_peerIo *     io,
 ***
 **/
 
-void
-tr_peerIoEnableFEXT( tr_peerIo * io,
-                     tr_bool     flag )
-{
-    assert( tr_isPeerIo( io ) );
-    assert( tr_isBool( flag ) );
-
-    dbgmsg( io, "setting FEXT support flag to %d", (flag!=0) );
-    io->fastExtensionSupported = flag;
-}
-
-void
-tr_peerIoEnableLTEP( tr_peerIo  * io,
-                     tr_bool      flag )
-{
-    assert( tr_isPeerIo( io ) );
-    assert( tr_isBool( flag ) );
-
-    dbgmsg( io, "setting LTEP support flag to %d", (flag!=0) );
-    io->extendedProtocolSupported = flag;
-}
-
-void
-tr_peerIoEnableDHT( tr_peerIo * io, tr_bool flag )
-{
-    assert( tr_isPeerIo( io ) );
-    assert( tr_isBool( flag ) );
-
-    dbgmsg( io, "setting DHT support flag to %d", (flag!=0) );
-    io->dhtSupported = flag;
-}
-
-/**
-***
-**/
-
-static size_t
+static unsigned int
 getDesiredOutputBufferSize( const tr_peerIo * io, uint64_t now )
 {
     /* this is all kind of arbitrary, but what seems to work well is
      * being large enough to hold the next 20 seconds' worth of input,
      * or a few blocks, whichever is bigger.
      * It's okay to tweak this as needed */
-    const double maxBlockSize = 16 * 1024; /* 16 KiB is from BT spec */
-    const double currentSpeed = tr_bandwidthGetPieceSpeed( &io->bandwidth, now, TR_UP );
-    const double period = 15; /* arbitrary */
-    const double numBlocks = 3.5; /* the 3 is arbitrary; the .5 is to leave room for messages */
-    return MAX( maxBlockSize*numBlocks, currentSpeed*1024*period );
+    const unsigned int currentSpeed_Bps = tr_bandwidthGetPieceSpeed_Bps( &io->bandwidth, now, TR_UP );
+    const unsigned int period = 15u; /* arbitrary */
+    /* the 3 is arbitrary; the .5 is to leave room for messages */
+    static const unsigned int ceiling =  (unsigned int)( MAX_BLOCK_SIZE * 3.5 );
+    return MAX( ceiling, currentSpeed_Bps*period );
 }
 
 size_t
@@ -765,8 +759,7 @@ tr_peerIoGetWriteBufferSpace( const tr_peerIo * io, uint64_t now )
 **/
 
 void
-tr_peerIoSetEncryption( tr_peerIo * io,
-                        int         encryptionMode )
+tr_peerIoSetEncryption( tr_peerIo * io, uint32_t encryptionMode )
 {
     assert( tr_isPeerIo( io ) );
     assert( encryptionMode == PEER_ENCRYPTION_NONE
@@ -838,6 +831,24 @@ tr_peerIoWriteBuf( tr_peerIo         * io,
     evbuffer_drain( buf, n );
 }
 
+void
+tr_peerIoWriteUint16( tr_peerIo        * io,
+                      struct evbuffer  * outbuf,
+                      uint16_t           writeme )
+{
+    const uint16_t tmp = htons( writeme );
+    tr_peerIoWriteBytes( io, outbuf, &tmp, sizeof( uint16_t ) );
+}
+
+void
+tr_peerIoWriteUint32( tr_peerIo        * io,
+                      struct evbuffer  * outbuf,
+                      uint32_t           writeme )
+{
+    const uint32_t tmp = htonl( writeme );
+    tr_peerIoWriteBytes( io, outbuf, &tmp, sizeof( uint32_t ) );
+}
+
 /***
 ****
 ***/
@@ -869,6 +880,25 @@ tr_peerIoReadBytes( tr_peerIo       * io,
     }
 }
 
+void
+tr_peerIoReadUint16( tr_peerIo        * io,
+                     struct evbuffer  * inbuf,
+                     uint16_t         * setme )
+{
+    uint16_t tmp;
+    tr_peerIoReadBytes( io, inbuf, &tmp, sizeof( uint16_t ) );
+    *setme = ntohs( tmp );
+}
+
+void tr_peerIoReadUint32( tr_peerIo        * io,
+                          struct evbuffer  * inbuf,
+                          uint32_t         * setme )
+{
+    uint32_t tmp;
+    tr_peerIoReadBytes( io, inbuf, &tmp, sizeof( uint32_t ) );
+    *setme = ntohl( tmp );
+}
+
 void
 tr_peerIoDrain( tr_peerIo       * io,
                 struct evbuffer * inbuf,
@@ -899,9 +929,10 @@ tr_peerIoTryRead( tr_peerIo * io, size_t howmuch )
     if(( howmuch = tr_bandwidthClamp( &io->bandwidth, TR_DOWN, howmuch )))
     {
         int e;
-        errno = 0;
-        res = evbuffer_read( io->inbuf, io->socket, howmuch );
-        e = errno;
+
+        EVUTIL_SET_SOCKET_ERROR( 0 );
+        res = evbuffer_read( io->inbuf, io->socket, (int)howmuch );
+        e = EVUTIL_SOCKET_ERROR( );
 
         dbgmsg( io, "read %d from peer (%s)", res, (res==-1?strerror(e):"") );
 
@@ -910,10 +941,12 @@ tr_peerIoTryRead( tr_peerIo * io, size_t howmuch )
 
         if( ( res <= 0 ) && ( io->gotError ) && ( e != EAGAIN ) && ( e != EINTR ) && ( e != EINPROGRESS ) )
         {
+            char errstr[512];
             short what = EVBUFFER_READ | EVBUFFER_ERROR;
             if( res == 0 )
                 what |= EVBUFFER_EOF;
-            dbgmsg( io, "tr_peerIoTryRead got an error. res is %d, what is %hd, errno is %d (%s)", res, what, e, strerror( e ) );
+            tr_net_strerror( errstr, sizeof( errstr ), e );
+            dbgmsg( io, "tr_peerIoTryRead got an error. res is %d, what is %hd, errno is %d (%s)", res, what, e, errstr );
             io->gotError( io, what, io->userData );
         }
     }
@@ -929,17 +962,20 @@ tr_peerIoTryWrite( tr_peerIo * io, size_t howmuch )
     if(( howmuch = tr_bandwidthClamp( &io->bandwidth, TR_UP, howmuch )))
     {
         int e;
-        errno = 0;
+        EVUTIL_SET_SOCKET_ERROR( 0 );
         n = tr_evbuffer_write( io, io->socket, howmuch );
-        e = errno;
+        e = EVUTIL_SOCKET_ERROR( );
 
         if( n > 0 )
             didWriteWrapper( io, n );
 
         if( ( n < 0 ) && ( io->gotError ) && ( e != EPIPE ) && ( e != EAGAIN ) && ( e != EINTR ) && ( e != EINPROGRESS ) )
         {
+            char errstr[512];
             const short what = EVBUFFER_WRITE | EVBUFFER_ERROR;
-            dbgmsg( io, "tr_peerIoTryWrite got an error. res is %d, what is %hd, errno is %d (%s)", n, what, e, strerror( e ) );
+
+            tr_net_strerror( errstr, sizeof( errstr ), e );
+            dbgmsg( io, "tr_peerIoTryWrite got an error. res is %d, what is %hd, errno is %d (%s)", n, what, e, errstr );
 
             if( io->gotError != NULL )
                 io->gotError( io, what, io->userData );
