@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-io.h 10671 2010-05-20 15:30:18Z charles $
+ * $Id: peer-io.h 11299 2010-10-11 15:41:27Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -29,6 +29,7 @@
 #include "bandwidth.h"
 #include "list.h" /* tr_list */
 #include "net.h" /* tr_address */
+#include "utils.h" /* tr_time() */
 
 struct evbuffer;
 struct tr_bandwidth;
@@ -77,11 +78,11 @@ typedef struct tr_peerIo
 
     tr_priority_t         priority;
 
-    int                   pendingEvents;
+    short int             pendingEvents;
 
     int                   magicNumber;
 
-    uint8_t               encryptionMode;
+    uint32_t              encryptionMode;
     tr_bool               isSeed;
 
     tr_port               port;
@@ -191,10 +192,7 @@ static inline tr_session* tr_peerIoGetSession ( tr_peerIo * io )
 const char* tr_peerIoAddrStr( const struct tr_address * addr,
                               tr_port                   port );
 
-static inline const char* tr_peerIoGetAddrStr( const tr_peerIo * io )
-{
-    return tr_isPeerIo( io ) ? tr_peerIoAddrStr( &io->addr, io->port ) : "error";
-}
+const char* tr_peerIoGetAddrStr( const tr_peerIo * io );
 
 const struct tr_address * tr_peerIoGetAddress( const tr_peerIo * io,
                                                tr_port         * port );
@@ -215,7 +213,7 @@ static inline tr_bool tr_peerIoIsIncoming( const tr_peerIo * io )
 
 static inline int    tr_peerIoGetAge( const tr_peerIo * io )
 {
-    return time( NULL ) - io->timeCreated;
+    return tr_time() - io->timeCreated;
 }
 
 
@@ -276,10 +274,10 @@ typedef enum
 }
 EncryptionMode;
 
-void      tr_peerIoSetEncryption( tr_peerIo * io,
-                                  int         encryptionMode );
+void tr_peerIoSetEncryption( tr_peerIo * io, uint32_t encryptionMode );
 
-static inline tr_bool tr_peerIoIsEncrypted( const tr_peerIo * io )
+static inline tr_bool
+tr_peerIoIsEncrypted( const tr_peerIo * io )
 {
     return ( io != NULL ) && ( io->encryptionMode == PEER_ENCRYPTION_RC4 );
 }
@@ -299,21 +297,13 @@ static inline void  tr_peerIoWriteUint8( tr_peerIo        * io,
     tr_peerIoWriteBytes( io, outbuf, &writeme, sizeof( uint8_t ) );
 }
 
-static inline void tr_peerIoWriteUint16( tr_peerIo        * io,
-                                            struct evbuffer  * outbuf,
-                                            uint16_t           writeme )
-{
-    const uint16_t tmp = htons( writeme );
-    tr_peerIoWriteBytes( io, outbuf, &tmp, sizeof( uint16_t ) );
-}
+void tr_peerIoWriteUint16( tr_peerIo        * io,
+                           struct evbuffer  * outbuf,
+                           uint16_t           writeme );
 
-static inline void tr_peerIoWriteUint32( tr_peerIo        * io,
-                                            struct evbuffer  * outbuf,
-                                            uint32_t           writeme )
-{
-    const uint32_t tmp = htonl( writeme );
-    tr_peerIoWriteBytes( io, outbuf, &tmp, sizeof( uint32_t ) );
-}
+void tr_peerIoWriteUint32( tr_peerIo        * io,
+                           struct evbuffer  * outbuf,
+                           uint32_t           writeme );
 
 void tr_peerIoReadBytes( tr_peerIo        * io,
                          struct evbuffer  * inbuf,
@@ -327,23 +317,13 @@ static inline void tr_peerIoReadUint8( tr_peerIo        * io,
     tr_peerIoReadBytes( io, inbuf, setme, sizeof( uint8_t ) );
 }
 
-static inline void tr_peerIoReadUint16( tr_peerIo        * io,
-                                           struct evbuffer  * inbuf,
-                                           uint16_t         * setme )
-{
-    uint16_t tmp;
-    tr_peerIoReadBytes( io, inbuf, &tmp, sizeof( uint16_t ) );
-    *setme = ntohs( tmp );
-}
+void tr_peerIoReadUint16( tr_peerIo        * io,
+                          struct evbuffer  * inbuf,
+                          uint16_t         * setme );
 
-static inline void tr_peerIoReadUint32( tr_peerIo        * io,
-                                           struct evbuffer  * inbuf,
-                                           uint32_t         * setme )
-{
-    uint32_t tmp;
-    tr_peerIoReadBytes( io, inbuf, &tmp, sizeof( uint32_t ) );
-    *setme = ntohl( tmp );
-}
+void tr_peerIoReadUint32( tr_peerIo        * io,
+                          struct evbuffer  * inbuf,
+                          uint32_t         * setme );
 
 void      tr_peerIoDrain( tr_peerIo        * io,
                           struct evbuffer  * inbuf,
@@ -368,8 +348,8 @@ void      tr_peerIoBandwidthUsed( tr_peerIo           * io,
                                   size_t                byteCount,
                                   int                   isPieceData );
 
-static inline tr_bool tr_peerIoHasBandwidthLeft( const tr_peerIo  * io,
-                                                    tr_direction       dir )
+static inline tr_bool
+tr_peerIoHasBandwidthLeft( const tr_peerIo * io, tr_direction dir )
 {
     assert( tr_isPeerIo( io ) );
 
@@ -377,12 +357,13 @@ static inline tr_bool tr_peerIoHasBandwidthLeft( const tr_peerIo  * io,
         || ( tr_bandwidthClamp( &io->bandwidth, dir, 1024 ) > 0 );
 }
 
-static inline double tr_peerIoGetPieceSpeed( const tr_peerIo * io, uint64_t now, tr_direction dir )
+static inline unsigned int
+tr_peerIoGetPieceSpeed_Bps( const tr_peerIo * io, uint64_t now, tr_direction dir )
 {
     assert( tr_isPeerIo( io ) );
     assert( tr_isDirection( dir ) );
 
-    return tr_bandwidthGetPieceSpeed( &io->bandwidth, now, dir );
+    return tr_bandwidthGetPieceSpeed_Bps( &io->bandwidth, now, dir );
 }
 
 /**
