@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-mgr.h 10751 2010-06-14 12:01:50Z charles $
+ * $Id: peer-mgr.h 11295 2010-10-08 13:33:50Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -28,7 +28,6 @@
 #include "history.h"
 #include "net.h"
 #include "peer-common.h" /* struct peer_request */
-#include "publish.h" /* tr_publisher_tag */
 
 /**
  * @addtogroup peers Peers
@@ -111,12 +110,6 @@ typedef struct tr_peer
 
     time_t                   chokeChangedAt;
 
-    time_t                   lastBlocksAtTime;
-    int                      blocksAt[60];
-
-    time_t                   lastCancelTime;
-    int                      cancelAt[60];
-
     tr_recentHistory       * blocksSentToClient;
     tr_recentHistory       * blocksSentToPeer;
 
@@ -124,7 +117,6 @@ typedef struct tr_peer
     tr_recentHistory       * cancelsSentToPeer;
 
     struct tr_peermsgs     * msgs;
-    tr_publisher_tag         msgsTag;
 }
 tr_peer;
 
@@ -227,14 +219,16 @@ void tr_peerMgrTorrentStats( tr_torrent * tor,
 struct tr_peer_stat* tr_peerMgrPeerStats( const tr_torrent * tor,
                                           int              * setmeCount );
 
-float tr_peerMgrGetWebseedSpeed( const tr_torrent * tor, uint64_t now );
+int tr_peerMgrGetWebseedSpeed_Bps( const tr_torrent * tor, uint64_t now );
 
-float* tr_peerMgrWebSpeeds( const tr_torrent * tor );
+double* tr_peerMgrWebSpeeds_KBps( const tr_torrent * tor );
 
 
-double tr_peerGetPieceSpeed( const tr_peer    * peer,
-                             uint64_t           now,
-                             tr_direction       direction );
+int tr_peerGetPieceSpeed_Bps( const tr_peer    * peer,
+                              uint64_t           now,
+                              tr_direction       direction );
+
+void tr_peerMgrClearInterest( tr_torrent * tor );
 
 /* @} */
 
