@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: platform.h 10634 2010-05-06 17:02:31Z charles $
+ * $Id: platform.h 11126 2010-08-05 19:54:44Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -17,17 +17,12 @@
 #ifndef TR_PLATFORM_H
 #define TR_PLATFORM_H
 
-#if defined( WIN32 )
- #define TR_PATH_DELIMITER '\\'
- #define TR_PATH_DELIMITER_STR "\\"
-#else
- #define TR_PATH_DELIMITER '/'
- #define TR_PATH_DELIMITER_STR "/"
-#endif
+#define TR_PATH_DELIMITER '/'
+#define TR_PATH_DELIMITER_STR "/"
 
 #ifdef WIN32
- #include <windows.h> /* MAX_PATH */
- #define TR_PATH_MAX MAX_PATH
+ #include <windef.h> /* MAX_PATH */
+ #define TR_PATH_MAX (MAX_PATH + 1)
 #else
  #include <limits.h> /* PATH_MAX */
  #ifdef PATH_MAX
@@ -74,7 +69,7 @@ tr_thread* tr_threadNew( void ( *func )(void *), void * arg );
 
 /** @brief Return nonzero if this function is being called from `thread'
     @param thread the thread being tested */
-int tr_amInThread( const tr_thread * );
+tr_bool tr_amInThread( const tr_thread * );
 
 /***
 ****
