@@ -1,5 +1,5 @@
 /*
- * This file Copyright (C) 2007-2008 Charles Kerr <charles@rebelbase.com>
+ * This file Copyright (C) 2007-2010 Mnemosyne LLC
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
@@ -7,10 +7,11 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: stats.c 7144 2008-11-23 17:40:35Z charles $
+ * $Id: stats.c 9973 2010-01-20 18:48:52Z charles $
  */
 
 #include "transmission.h"
+#include "session.h"
 #include "bencode.h"
 #include "platform.h" /* tr_sessionGetConfigDir() */
 #include "stats.h"
@@ -20,43 +21,45 @@
 ****
 ***/
 
-static struct tr_session_stats STATS_INIT = { 0.0f, 0, 0, 0, 0, 0 };
+static const struct tr_session_stats STATS_INIT = { 0.0f, 0, 0, 0, 0, 0 };
 
+/** @brief Opaque, per-session data structure for bandwidth use statistics */
 struct tr_stats_handle
 {
     tr_session_stats    single;
     tr_session_stats    old;
     time_t              startTime;
+    tr_bool             isDirty;
 };
 
 static char*
-getOldFilename( const tr_handle * handle )
+getOldFilename( const tr_session * session )
 {
-    return tr_buildPath( tr_sessionGetConfigDir( handle ), "stats.benc", NULL );
+    return tr_buildPath( tr_sessionGetConfigDir( session ), "stats.benc", NULL );
 }
 
 static char*
-getFilename( const tr_handle * handle )
+getFilename( const tr_session * session )
 {
-    return tr_buildPath( tr_sessionGetConfigDir( handle ), "stats.json", NULL );
+    return tr_buildPath( tr_sessionGetConfigDir( session ), "stats.json", NULL );
 }
 
 static void
-loadCumulativeStats( const tr_handle *  handle,
+loadCumulativeStats( const tr_session * session,
                      tr_session_stats * setme )
 {
     int     loaded = FALSE;
     char   * filename;
     tr_benc top;
 
-    filename = getFilename( handle );
-    loaded = !tr_bencLoadJSONFile( filename, &top );
+    filename = getFilename( session );
+    loaded = !tr_bencLoadFile( &top, TR_FMT_JSON, filename );
     tr_free( filename );
 
     if( !loaded )
     {
-        filename = getOldFilename( handle );
-        loaded = !tr_bencLoadFile( filename, &top );
+        filename = getOldFilename( session );
+        loaded = !tr_bencLoadFile( &top, TR_FMT_BENC, filename );
         tr_free( filename );
     }
 
@@ -80,7 +83,7 @@ loadCumulativeStats( const tr_handle *  handle,
 }
 
 static void
-saveCumulativeStats( const tr_handle *        handle,
+saveCumulativeStats( const tr_session * session,
                      const tr_session_stats * s )
 {
     char * filename;
@@ -93,9 +96,9 @@ saveCumulativeStats( const tr_handle *        handle,
     tr_bencDictAddInt( &top, "session-count",    s->sessionCount );
     tr_bencDictAddInt( &top, "uploaded-bytes",   s->uploadedBytes );
 
-    filename = getFilename( handle );
+    filename = getFilename( session );
     tr_deepLog( __FILE__, __LINE__, NULL, "Saving stats to \"%s\"", filename );
-    tr_bencSaveJSONFile( filename, &top );
+    tr_bencToFile( &top, TR_FMT_JSON, filename );
 
     tr_free( filename );
     tr_bencFree( &top );
@@ -106,32 +109,42 @@ saveCumulativeStats( const tr_handle *        handle,
 ***/
 
 void
-tr_statsInit( tr_handle * handle )
+tr_statsInit( tr_session * session )
 {
     struct tr_stats_handle * stats = tr_new0( struct tr_stats_handle, 1 );
 
-    loadCumulativeStats( handle, &stats->old );
+    loadCumulativeStats( session, &stats->old );
     stats->single.sessionCount = 1;
-    stats->startTime = time( NULL );
-    handle->sessionStats = stats;
-}
-
-void
-tr_statsClose( tr_handle * handle )
-{
-    tr_session_stats cumulative = STATS_INIT;
-
-    tr_sessionGetCumulativeStats( handle, &cumulative );
-    saveCumulativeStats( handle, &cumulative );
-
-    tr_free( handle->sessionStats );
-    handle->sessionStats = NULL;
+    stats->startTime = tr_time( );
+    session->sessionStats = stats;
 }
 
 static struct tr_stats_handle *
-getStats( const tr_handle * handle )
+getStats( const tr_session * session )
 {
-    return handle ? handle->sessionStats : NULL;
+    return session ? session->sessionStats : NULL;
+}
+
+void
+tr_statsSaveDirty( tr_session * session )
+{
+    struct tr_stats_handle * h = getStats( session );
+    if( ( h != NULL ) && h->isDirty )
+    {
+        tr_session_stats cumulative = STATS_INIT;
+        tr_sessionGetCumulativeStats( session, &cumulative );
+        saveCumulativeStats( session, &cumulative );
+        h->isDirty = FALSE;
+    }
+}
+
+void
+tr_statsClose( tr_session * session )
+{
+    tr_statsSaveDirty( session );
+
+    tr_free( session->sessionStats );
+    session->sessionStats = NULL;
 }
 
 /***
@@ -159,34 +172,34 @@ addStats( tr_session_stats *       setme,
 }
 
 void
-tr_sessionGetStats( const tr_handle *  handle,
+tr_sessionGetStats( const tr_session * session,
                     tr_session_stats * setme )
 {
-    const struct tr_stats_handle * stats = getStats( handle );
+    const struct tr_stats_handle * stats = getStats( session );
     if( stats )
     {
         *setme = stats->single;
-        setme->secondsActive = time( NULL ) - stats->startTime;
+        setme->secondsActive = tr_time( ) - stats->startTime;
         updateRatio( setme );
     }
 }
 
 void
-tr_sessionGetCumulativeStats( const tr_handle *  handle,
+tr_sessionGetCumulativeStats( const tr_session * session,
                               tr_session_stats * setme )
 {
-    const struct tr_stats_handle * stats = getStats( handle );
+    const struct tr_stats_handle * stats = getStats( session );
     tr_session_stats current = STATS_INIT;
 
     if( stats )
     {
-        tr_sessionGetStats( handle, &current );
+        tr_sessionGetStats( session, &current );
         addStats( setme, &stats->old, &current );
     }
 }
 
 void
-tr_sessionClearStats( tr_handle * handle )
+tr_sessionClearStats( tr_session * session )
 {
     tr_session_stats zero;
 
@@ -196,9 +209,9 @@ tr_sessionClearStats( tr_handle * handle )
     zero.filesAdded = 0;
     zero.sessionCount = 0;
     zero.secondsActive = 0;
-    handle->sessionStats->single = handle->sessionStats->old = zero;
 
-    handle->sessionStats->startTime = time( NULL );
+    session->sessionStats->single = session->sessionStats->old = zero;
+    session->sessionStats->startTime = tr_time( );
 }
 
 /**
@@ -206,31 +219,37 @@ tr_sessionClearStats( tr_handle * handle )
 **/
 
 void
-tr_statsAddUploaded( tr_handle * handle,
+tr_statsAddUploaded( tr_session * session,
                      uint32_t    bytes )
 {
     struct tr_stats_handle * s;
 
-    if( ( s = getStats( handle ) ) )
+    if( ( s = getStats( session ) ) )
+    {
         s->single.uploadedBytes += bytes;
+        s->isDirty = TRUE;
+    }
 }
 
 void
-tr_statsAddDownloaded( tr_handle * handle,
-                       uint32_t    bytes )
+tr_statsAddDownloaded( tr_session * session,
+                       uint32_t     bytes )
 {
     struct tr_stats_handle * s;
 
-    if( ( s = getStats( handle ) ) )
+    if( ( s = getStats( session ) ) )
+    {
         s->single.downloadedBytes += bytes;
+        s->isDirty = TRUE;
+    }
 }
 
 void
-tr_statsFileCreated( tr_handle * handle )
+tr_statsFileCreated( tr_session * session )
 {
     struct tr_stats_handle * s;
 
-    if( ( s = getStats( handle ) ) )
+    if( ( s = getStats( session ) ) )
         s->single.filesAdded++;
 }
 
