@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: torrent-ctor.c 10565 2010-05-01 03:38:02Z charles $
+ * $Id: torrent-ctor.c 10531 2010-04-26 22:00:34Z charles $
  */
 
 #include <errno.h> /* EINVAL */
@@ -430,7 +430,6 @@ isPriority( int i )
 void
 tr_ctorSetBandwidthPriority( tr_ctor * ctor, tr_priority_t priority )
 {
-fprintf( stderr, "in tr_ctorSetPriority with %d\n", (int)priority );
     if( isPriority( priority ) )
         ctor->bandwidthPriority = priority;
 }
@@ -452,8 +451,10 @@ tr_ctorNew( const tr_session * session )
 
     ctor->session = session;
     ctor->bandwidthPriority = TR_PRI_NORMAL;
-    tr_ctorSetPaused( ctor, TR_FALLBACK, FALSE );
-    if( session != NULL ) {
+    if( session != NULL )
+    {
+        tr_ctorSetDeleteSource( ctor, tr_sessionGetDeleteSource( session ) );
+        tr_ctorSetPaused( ctor, TR_FALLBACK, tr_sessionGetPaused( session ) );
         tr_ctorSetPeerLimit( ctor, TR_FALLBACK, session->peerLimitPerTorrent );
         tr_ctorSetDownloadDir( ctor, TR_FALLBACK, session->downloadDir );
     }
