@@ -18,6 +18,9 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
+
+ $Id: tr-dht.c 11359 2010-10-30 01:48:45Z charles $
+
 */
 
 /* ansi */
@@ -25,13 +28,19 @@ THE SOFTWARE.
 #include <stdio.h>
 
 /* posix */
-#include <netinet/in.h> /* sockaddr_in */
 #include <signal.h> /* sig_atomic_t */
 #include <sys/time.h>
-#include <sys/types.h>
-#include <sys/socket.h> /* socket(), bind() */
-#include <netdb.h>
 #include <unistd.h> /* close() */
+#ifdef WIN32
+  #include <inttypes.h>
+  #define _WIN32_WINNT  0x0501	/* freeaddrinfo(),getaddrinfo(),getnameinfo() */
+  #include <ws2tcpip.h>
+#else
+  #include <sys/types.h>
+  #include <sys/socket.h> /* socket(), bind() */
+  #include <netdb.h>
+  #include <netinet/in.h> /* sockaddr_in */
+#endif
 
 /* third party */
 #include <event.h>
@@ -49,7 +58,6 @@ THE SOFTWARE.
 #include "tr-dht.h"
 #include "trevent.h" /* tr_runInEventThread() */
 #include "utils.h"
-#include "version.h"
 
 static int dht_socket = -1, dht6_socket = -1;
 static struct event dht_event, dht6_event;
@@ -81,12 +89,11 @@ bootstrap_done( tr_session *session, int af )
 }
 
 static void
-nap( int roughly )
+nap( int roughly_sec )
 {
-    struct timeval tv;
-    tv.tv_sec = roughly / 2 + tr_cryptoWeakRandInt( roughly );
-    tv.tv_usec = tr_cryptoWeakRandInt( 1000000 );
-    select( 0, NULL, NULL, NULL, &tv );
+    const int roughly_msec = roughly_sec * 1000;
+    const int msec = roughly_msec/2 + tr_cryptoWeakRandInt(roughly_msec);
+    tr_wait_msec( msec );
 }
 
 static int
@@ -193,7 +200,7 @@ dht_bootstrap(void *closure)
             tr_buildPath(cl->session->configDir, "dht.bootstrap", NULL);
 
         if(bootstrap_file)
-            f = fopen(bootstrap_file, "r");
+            f = fopen(bootstrap_file, "rb");
         if(f != NULL) {
             tr_ninf("DHT", "Attempting manual bootstrap");
             for(;;) {
@@ -248,39 +255,62 @@ dht_bootstrap(void *closure)
    IPv6 address, if I may say so myself. */
 
 static int
-rebind_ipv6(int force)
+rebind_ipv6(tr_bool force)
 {
     struct sockaddr_in6 sin6;
     const unsigned char *ipv6 = tr_globalIPv6();
     static unsigned char *last_bound = NULL;
-    int rc;
+    int s, rc;
+    int one = 1;
 
-    if(dht6_socket < 0)
+    /* We currently have no way to enable or disable IPv6 once the DHT has
+       been initialised.  Oh, well. */
+    if(ipv6 == NULL || (!force && dht6_socket < 0)) {
+        if(last_bound) {
+            free(last_bound);
+            last_bound = NULL;
+        }
+        return 0;
+    }
+
+    if(last_bound != NULL && memcmp(ipv6, last_bound, 16) == 0)
         return 0;
 
-    if(!force &&
-       ((ipv6 == NULL && last_bound == NULL) ||
-        (ipv6 != NULL && last_bound != NULL &&
-         memcmp(ipv6, last_bound, 16) == 0)))
-        return 0;
+    s = socket(PF_INET6, SOCK_DGRAM, 0);
+    if(s < 0)
+        return -1;
+
+#ifdef IPV6_V6ONLY
+        /* Since we always open an IPv4 socket on the same port, this
+           shouldn't matter.  But I'm superstitious. */
+        setsockopt(s, IPPROTO_IPV6, IPV6_V6ONLY, &one, sizeof(one));
+#endif
 
     memset(&sin6, 0, sizeof(sin6));
     sin6.sin6_family = AF_INET6;
     if(ipv6)
         memcpy(&sin6.sin6_addr, ipv6, 16);
     sin6.sin6_port = htons(dht_port);
-    rc = bind(dht6_socket, (struct sockaddr*)&sin6, sizeof(sin6));
+    rc = bind(s, (struct sockaddr*)&sin6, sizeof(sin6));
 
-    if(last_bound)
-        free(last_bound);
-    last_bound = NULL;
+    if(rc < 0)
+        return -1;
 
-    if(rc >= 0 && ipv6) {
-        last_bound = malloc(16);
-        if(last_bound)
-            memcpy(last_bound, ipv6, 16);
+    if(dht6_socket < 0) {
+        dht6_socket = s;
+    } else {
+        rc = dup2(s, dht6_socket);
+        close(s);
+        if(rc < 0)
+            return -1;
     }
-    return rc;
+
+    if(last_bound == NULL)
+        last_bound = malloc(16);
+    if(last_bound)
+        memcpy(last_bound, ipv6, 16);
+
+    return 1;
 }
 
 int
@@ -294,7 +324,6 @@ tr_dhtInit(tr_session *ss, const tr_address * tr_addr)
     uint8_t * nodes = NULL, * nodes6 = NULL;
     const uint8_t * raw;
     size_t len, len6;
-    char v[5];
     struct bootstrap_closure * cl;
 
     if( session ) /* already initialized */
@@ -318,22 +347,8 @@ tr_dhtInit(tr_session *ss, const tr_address * tr_addr)
     if(rc < 0)
         goto fail;
 
-    if(tr_globalIPv6()) {
-        int one = 1;
-        dht6_socket = socket(PF_INET6, SOCK_DGRAM, 0);
-        if(dht6_socket < 0)
-            goto fail;
-
-#ifdef IPV6_V6ONLY
-        /* Since we always open an IPv4 socket on the same port, this
-           shouldn't matter.  But I'm superstitious. */
-        setsockopt(dht6_socket, IPPROTO_IPV6, IPV6_V6ONLY,
-                   &one, sizeof(one));
-#endif
-
-        rebind_ipv6(1);
-
-    }
+    if(tr_globalIPv6())
+        rebind_ipv6(TRUE);
 
     if( getenv( "TR_DHT_VERBOSE" ) != NULL )
         dht_debug = stderr;
@@ -370,12 +385,8 @@ tr_dhtInit(tr_session *ss, const tr_address * tr_addr)
         tr_cryptoRandBuf( myid, 20 );
     }
 
-    v[0] = 'T';
-    v[1] = 'R';
-    v[2] = (SVN_REVISION_NUM >> 8) & 0xFF;
-    v[3] = SVN_REVISION_NUM & 0xFF;
-    rc = dht_init( dht_socket, dht6_socket, myid, (const unsigned char*)v );
-    if(rc < 0)
+    rc = dht_init( dht_socket, dht6_socket, myid, NULL );
+    if( rc < 0 )
         goto fail;
 
     session = ss;
@@ -529,7 +540,7 @@ tr_dhtStatus( tr_session * session, int af, int * nodes_return )
 
     tr_runInEventThread( session, getstatus, &closure );
     while( closure.status < 0 )
-        tr_wait_msec( 10 /*msec*/ );
+        tr_wait_msec( 50 /*msec*/ );
 
     if( nodes_return )
         *nodes_return = closure.count;
@@ -613,7 +624,7 @@ callback( void *ignore UNUSED, int event,
             else
                 pex = tr_peerMgrCompact6ToPex(data, data_len, NULL, 0, &n);
             for( i=0; i<n; ++i )
-                tr_peerMgrAddPex( tor, TR_PEER_FROM_DHT, pex+i );
+                tr_peerMgrAddPex( tor, TR_PEER_FROM_DHT, pex+i, -1 );
             tr_free(pex);
             tr_tordbg(tor, "Learned %d%s peers from DHT",
                       (int)n,
@@ -698,8 +709,8 @@ event_callback(int s, short type, void *ignore UNUSED )
     /* Only do this once in a while.  Counting rather than measuring time
        avoids a system call. */
     count++;
-    if(count >= 128) {
-        rebind_ipv6(0);
+    if(count >= 20) {
+        rebind_ipv6(FALSE);
         count = 0;
     }
 
