@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: trevent.c 10886 2010-06-26 21:10:05Z charles $
+ * $Id: trevent.c 10913 2010-06-30 21:24:36Z charles $
  */
 
 #include <assert.h>
@@ -26,79 +26,94 @@
 
 #ifdef WIN32
 
-#include <WinSock2.h>
+#include "utils.h"
+#include <winsock2.h>
 
 static int
 pgpipe( int handles[2] )
 {
-        SOCKET s;
-        struct sockaddr_in serv_addr;
-        int len = sizeof( serv_addr );
+    SOCKET s;
+    struct sockaddr_in serv_addr;
+    int len = sizeof( serv_addr );
 
-        handles[0] = handles[1] = INVALID_SOCKET;
+    handles[0] = handles[1] = INVALID_SOCKET;
 
-        if ( ( s = socket( AF_INET, SOCK_STREAM, 0 ) ) == INVALID_SOCKET )
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to create socket: %ui", WSAGetLastError()))); */
-                return -1;
-        }
+    if ( ( s = socket( AF_INET, SOCK_STREAM, 0 ) ) == INVALID_SOCKET )
+    {
+        tr_dbg("pgpipe failed to create socket: %ui", WSAGetLastError());
+        return -1;
+    }
 
-        memset( &serv_addr, 0, sizeof( serv_addr ) );
-        serv_addr.sin_family = AF_INET;
-        serv_addr.sin_port = htons(0);
-        serv_addr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-        if (bind(s, (SOCKADDR *) & serv_addr, len) == SOCKET_ERROR)
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to bind: %ui", WSAGetLastError()))); */
-                closesocket(s);
-                return -1;
-        }
-        if (listen(s, 1) == SOCKET_ERROR)
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to listen: %ui", WSAGetLastError()))); */
-                closesocket(s);
-                return -1;
-        }
-        if (getsockname(s, (SOCKADDR *) & serv_addr, &len) == SOCKET_ERROR)
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to getsockname: %ui", WSAGetLastError()))); */
-                closesocket(s);
-                return -1;
-        }
-        if ((handles[1] = socket(PF_INET, SOCK_STREAM, 0)) == INVALID_SOCKET)
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to create socket 2: %ui", WSAGetLastError()))); */
-                closesocket(s);
-                return -1;
-        }
-
-        if (connect(handles[1], (SOCKADDR *) & serv_addr, len) == SOCKET_ERROR)
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to connect socket: %ui", WSAGetLastError()))); */
-                closesocket(s);
-                return -1;
-        }
-        if ((handles[0] = accept(s, (SOCKADDR *) & serv_addr, &len)) == INVALID_SOCKET)
-        {
-/*              ereport(LOG, (errmsg_internal("pgpipe failed to accept socket: %ui", WSAGetLastError()))); */
-                closesocket(handles[1]);
-                handles[1] = INVALID_SOCKET;
-                closesocket(s);
-                return -1;
-        }
+    memset( &serv_addr, 0, sizeof( serv_addr ) );
+    serv_addr.sin_family = AF_INET;
+    serv_addr.sin_port = htons(0);
+    serv_addr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+    if (bind(s, (SOCKADDR *) & serv_addr, len) == SOCKET_ERROR)
+    {
+        tr_dbg("pgpipe failed to bind: %ui", WSAGetLastError());
         closesocket(s);
-        return 0;
+        return -1;
+    }
+    if (listen(s, 1) == SOCKET_ERROR)
+    {
+        tr_ndbg("event","pgpipe failed to listen: %ui", WSAGetLastError());
+        closesocket(s);
+        return -1;
+    }
+    if (getsockname(s, (SOCKADDR *) & serv_addr, &len) == SOCKET_ERROR)
+    {
+        tr_dbg("pgpipe failed to getsockname: %ui", WSAGetLastError());
+        closesocket(s);
+        return -1;
+    }
+    if ((handles[1] = socket(PF_INET, SOCK_STREAM, 0)) == INVALID_SOCKET)
+    {
+        tr_dbg("pgpipe failed to create socket 2: %ui", WSAGetLastError());
+        closesocket(s);
+        return -1;
+    }
+
+    if (connect(handles[1], (SOCKADDR *) & serv_addr, len) == SOCKET_ERROR)
+    {
+        tr_dbg("pgpipe failed to connect socket: %ui", WSAGetLastError());
+        closesocket(s);
+        return -1;
+    }
+    if ((handles[0] = accept(s, (SOCKADDR *) & serv_addr, &len)) == INVALID_SOCKET)
+    {
+        tr_dbg("pgpipe failed to accept socket: %ui", WSAGetLastError());
+        closesocket(handles[1]);
+        handles[1] = INVALID_SOCKET;
+        closesocket(s);
+        return -1;
+    }
+    closesocket(s);
+    return 0;
 }
 
 static int
 piperead( int s, char *buf, int len )
 {
-        int ret = recv(s, buf, len, 0);
+    int ret = recv(s, buf, len, 0);
 
-        if (ret < 0 && WSAGetLastError() == WSAECONNRESET)
-                /* EOF on the pipe! (win32 socket based implementation) */
-                ret = 0;
-        return ret;
+    if (ret < 0) {
+        const int werror= WSAGetLastError();
+        switch(werror) {
+          /* simplified error mapping (not valid for connect) */
+            case WSAEWOULDBLOCK:
+                errno = EAGAIN;
+                break;
+	    case WSAECONNRESET:
+	        /* EOF on the pipe! (win32 socket based implementation) */
+	        ret = 0;
+	        /* fall through */
+            default:
+                errno = werror;
+                break;
+        }
+    } else
+        errno = 0;
+    return ret;
 }
 
 #define pipe(a) pgpipe(a)
