@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: upnp.c 10581 2010-05-01 04:32:15Z charles $
+ * $Id: upnp.c 10900 2010-06-27 15:29:23Z charles $
  */
 
 #include <assert.h>
@@ -77,6 +77,14 @@ tr_upnpClose( tr_upnp * handle )
 ***
 **/
 
+enum
+{
+  UPNP_IGD_NONE = 0,
+  UPNP_IGD_VALID_CONNECTED = 1,
+  UPNP_IGD_VALID_NOT_CONNECTED = 2,
+  UPNP_IGD_INVALID = 3
+};
+
 int
 tr_upnpPulse( tr_upnp * handle,
               int       port,
@@ -98,7 +106,7 @@ tr_upnpPulse( tr_upnp * handle,
         }
         errno = 0;
         if( UPNP_GetValidIGD( devlist, &handle->urls, &handle->data,
-                             handle->lanaddr, sizeof( handle->lanaddr ) ) )
+                             handle->lanaddr, sizeof( handle->lanaddr ) ) == UPNP_IGD_VALID_CONNECTED )
         {
             tr_ninf( getKey( ), _(
                          "Found Internet Gateway Device \"%s\"" ),
