@@ -1,5 +1,5 @@
 /*
- * This file Copyright (C) 2007-2008 Charles Kerr <charles@rebelbase.com>
+ * This file Copyright (C) 2007-2010 Mnemosyne LLC
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: upnp.h 7175 2008-11-29 16:32:10Z charles $
+ * $Id: upnp.h 9868 2010-01-04 21:00:47Z charles $
  */
 
 #ifndef __TRANSMISSION__
@@ -17,6 +17,11 @@
 #ifndef TR_UPNP_H
 #define TR_UPNP_H 1
 
+/**
+ * @addtogroup port_forwarding Port Forwarding
+ * @{
+ */
+
 typedef struct tr_upnp tr_upnp;
 
 tr_upnp * tr_upnpInit( void );
@@ -25,6 +30,7 @@ void      tr_upnpClose( tr_upnp * );
 
 int       tr_upnpPulse(         tr_upnp *,
                             int port,
-                            int isEnabled );
-
+                            int isEnabled,
+                            int doPortCheck );
+/* @} */
 #endif
