@@ -1,3 +1,4 @@
+#include <math.h>
 #include <stdio.h> /* fprintf */
 #include <string.h> /* strcmp */
 
@@ -102,6 +103,28 @@ test_bitfields( void )
     return 0;
 }
 
+static int
+test_strip_positional_args( void )
+{
+    const char * in;
+    const char * out;
+    const char * expected;
+
+    in = "Hello %1$s foo %2$.*f";
+    expected = "Hello %s foo %.*f";
+    out = tr_strip_positional_args( in );
+    check( out != NULL )
+    check( !strcmp( out, expected ) )
+
+    in = "Hello %1$'d foo %2$'f";
+    expected = "Hello %d foo %f";
+    out = tr_strip_positional_args( in );
+    check( out != NULL )
+    check( !strcmp( out, expected ) )
+
+    return 0;
+}
+
 static int
 test_strstrip( void )
 {
@@ -300,11 +323,11 @@ test_array( void )
     int array[10] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     int n = sizeof( array ) / sizeof( array[0] );
 
-    tr_removeElementFromArray( array, 5, sizeof( int ), n-- );
+    tr_removeElementFromArray( array, 5u, sizeof( int ), n-- );
     for( i=0; i<n; ++i )
         check( array[i] == ( i<5 ? i : i+1 ) );
 
-    tr_removeElementFromArray( array, 0, sizeof( int ), n-- );
+    tr_removeElementFromArray( array, 0u, sizeof( int ), n-- );
     for( i=0; i<n; ++i )
         check( array[i] == ( i<4 ? i+1 : i+2 ) );
 
@@ -357,6 +380,7 @@ static int
 test_truncd( void )
 {
     char buf[32];
+    const double nan = sqrt( -1 );
 
     tr_snprintf( buf, sizeof( buf ), "%.2f%%", 99.999 );
     check( !strcmp( buf, "100.00%" ) );
@@ -367,6 +391,21 @@ test_truncd( void )
     tr_snprintf( buf, sizeof( buf ), "%.4f", tr_truncd( 403650.656250, 4 ) );
     check( !strcmp( buf, "403650.6562" ) );
 
+    tr_snprintf( buf, sizeof( buf ), "%.2f", tr_truncd( 2.15, 2 ) );
+    check( !strcmp( buf, "2.15" ) );
+
+    tr_snprintf( buf, sizeof( buf ), "%.2f", tr_truncd( 2.05, 2 ) );
+    check( !strcmp( buf, "2.05" ) );
+
+    tr_snprintf( buf, sizeof( buf ), "%.2f", tr_truncd( 3.3333, 2 ) );
+    check( !strcmp( buf, "3.33" ) );
+
+    tr_snprintf( buf, sizeof( buf ), "%.0f", tr_truncd( 3.3333, 0 ) );
+    check( !strcmp( buf, "3" ) );
+
+    tr_snprintf( buf, sizeof( buf ), "%.2f", tr_truncd( nan, 2 ) );
+    check( !strcmp( buf, "nan" ) );
+
     return 0;
 }
 
@@ -397,6 +436,8 @@ main( void )
         return i;
     if( ( i = test_lowerbound( ) ) )
         return i;
+    if( ( i = test_strip_positional_args( ) ) )
+        return i;
     if( ( i = test_strstrip( ) ) )
         return i;
     if( ( i = test_buildpath( ) ) )
