@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: utils.h 11299 2010-10-11 15:41:27Z charles $
+ * $Id: utils.h 11490 2010-12-08 14:57:34Z charles $
  */
 
 #ifndef TR_UTILS_H
@@ -392,6 +392,9 @@ tr_bool tr_str_has_suffix( const char *str, const char *suffix );
 const char* tr_memmem( const char * haystack, size_t haystack_len,
                        const char * needle, size_t needle_len );
 
+/** @brief Portability wrapper for strsep() that uses the system implementation if available */
+char* tr_strsep( char ** str, const char * delim );
+
 /***
 ****
 ***/
