@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: webseed.c 10500 2010-04-20 21:54:03Z charles $
+ * $Id: webseed.c 10931 2010-07-03 00:25:22Z charles $
  */
 
 #include <string.h> /* strlen */
@@ -31,8 +31,8 @@ struct tr_webseed
 
     char              * url;
 
-    tr_delivery_func  * callback;
-    void *              callback_userdata;
+    tr_peer_callback  * callback;
+    void              * callback_data;
 
     tr_piece_index_t    pieceIndex;
     uint32_t            pieceOffset;
@@ -52,11 +52,10 @@ struct tr_webseed
 static const tr_peer_event blankEvent = { 0, 0, 0, 0, 0.0f, 0, 0, 0 };
 
 static void
-publish( tr_webseed *    w,
-         tr_peer_event * e )
+publish( tr_webseed * w, tr_peer_event * e )
 {
-    if( w->callback )
-        w->callback( NULL, e, w->callback_userdata );
+    if( w->callback != NULL )
+        w->callback( NULL, e, w->callback_data );
 }
 
 static void
@@ -222,11 +221,10 @@ tr_webseedIsActive( const tr_webseed * w )
 }
 
 int
-tr_webseedGetSpeed( const tr_webseed * w, uint64_t now, float * setme_KiBs )
+tr_webseedGetSpeed_Bps( const tr_webseed * w, uint64_t now, int * setme_Bps )
 {
     const int isActive = tr_webseedIsActive( w );
-
-    *setme_KiBs = isActive ? tr_rcRate( &w->rateDown, now ) : 0.0f;
+    *setme_Bps = isActive ? tr_rcRate_Bps( &w->rateDown, now ) : 0;
     return isActive;
 }
 
@@ -236,9 +234,9 @@ tr_webseedGetSpeed( const tr_webseed * w, uint64_t now, float * setme_KiBs )
 
 tr_webseed*
 tr_webseedNew( struct tr_torrent * torrent,
-               const char *        url,
-               tr_delivery_func    callback,
-               void *              callback_userdata )
+               const char        * url,
+               tr_peer_callback  * callback,
+               void              * callback_data )
 {
     tr_webseed * w = tr_new0( tr_webseed, 1 );
 
@@ -247,9 +245,8 @@ tr_webseedNew( struct tr_torrent * torrent,
     w->content = evbuffer_new( );
     w->url = tr_strdup( url );
     w->callback = callback;
-    w->callback_userdata = callback_userdata;
+    w->callback_data = callback_data;
     tr_rcConstruct( &w->rateDown );
-/*fprintf( stderr, "w->callback_userdata is %p\n", w->callback_userdata );*/
     return w;
 }
 
