@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: AddWindowController.m 10493 2010-04-17 14:01:55Z livings124 $
+ * $Id: AddWindowController.m 11418 2010-11-14 21:04:25Z livings124 $
  *
  * Copyright (c) 2008-2010 Transmission authors and contributors
  *
@@ -236,7 +236,8 @@
         NSString * fileString;
         NSInteger count = [fTorrent fileCount];
         if (count != 1)
-            fileString = [NSString stringWithFormat: NSLocalizedString(@"%d files", "Add torrent -> info"), count];
+            fileString = [NSString stringWithFormat: NSLocalizedString(@"%@ files", "Add torrent -> info"),
+                            [NSString formattedUInteger: count]];
         else
             fileString = NSLocalizedString(@"1 file", "Add torrent -> info");
         
