@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: BlocklistScheduler.m 9844 2010-01-01 21:12:04Z livings124 $
+ * $Id: BlocklistScheduler.m 11399 2010-11-13 16:07:27Z livings124 $
  *
  * Copyright (c) 2008-2010 Transmission authors and contributors
  *
@@ -55,11 +55,14 @@ BlocklistScheduler * fScheduler = nil;
     
     [self cancelSchedule];
     
-    if (![[NSUserDefaults standardUserDefaults] boolForKey: @"Blocklist"]
+    NSString * blocklistURL;
+    if (![[NSUserDefaults standardUserDefaults] boolForKey: @"BlocklistNew"]
+        || !((blocklistURL = [[NSUserDefaults standardUserDefaults] stringForKey: @"BlocklistURL"]) &&
+                ![blocklistURL isEqualToString: @""])
         || ![[NSUserDefaults standardUserDefaults] boolForKey: @"BlocklistAutoUpdate"])
         return;
     
-    NSDate * lastUpdateDate = [[NSUserDefaults standardUserDefaults] objectForKey: @"BlocklistLastUpdate"];
+    NSDate * lastUpdateDate = [[NSUserDefaults standardUserDefaults] objectForKey: @"BlocklistNewLastUpdate"];
     if (lastUpdateDate)
         lastUpdateDate = [lastUpdateDate dateByAddingTimeInterval: FULL_WAIT];
     NSDate * closeDate = [NSDate dateWithTimeIntervalSinceNow: SMALL_DELAY];
