@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: CreatorWindowController.m 10669 2010-05-20 00:16:49Z livings124 $
+ * $Id: CreatorWindowController.m 11418 2010-11-14 21:04:25Z livings124 $
  *
  * Copyright (c) 2007-2010 Transmission authors and contributors
  *
@@ -157,7 +157,8 @@
         NSString * fileString;
         NSInteger count = fInfo->fileCount;
         if (count != 1)
-            fileString = [NSString stringWithFormat: NSLocalizedString(@"%d files", "Create torrent -> info"), count];
+            fileString = [NSString stringWithFormat: NSLocalizedString(@"%@ files", "Create torrent -> info"),
+                            [NSString formattedUInteger: count]];
         else
             fileString = NSLocalizedString(@"1 file", "Create torrent -> info");
         statusString = [NSString stringWithFormat: @"%@, %@", fileString, statusString];
