@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: FileOutlineController.m 8422 2009-05-18 22:27:40Z livings124 $
+ * $Id: FileOutlineController.m 10206 2010-02-15 14:56:14Z livings124 $
  *
- * Copyright (c) 2008-2009 Transmission authors and contributors
+ * Copyright (c) 2008-2010 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -27,7 +27,8 @@
 #import "FileOutlineView.h"
 #import "FilePriorityCell.h"
 #import "FileListNode.h"
-#import "QuickLookController.h"
+#import "NSApplicationAdditions.h"
+#import <Quartz/Quartz.h>
 
 #define ROW_SMALL_HEIGHT 18.0
 
@@ -131,7 +132,9 @@ typedef enum
 
 - (void) outlineViewSelectionDidChange: (NSNotification *) notification
 {
-    [[QuickLookController quickLook] updateQuickLook];
+    if ([NSApp isOnSnowLeopardOrBetter] && [QLPreviewPanelSL sharedPreviewPanelExists]
+        && [[QLPreviewPanelSL sharedPreviewPanel] isVisible])
+        [[QLPreviewPanelSL sharedPreviewPanel] reloadData];
 }
 
 - (NSInteger) outlineView: (NSOutlineView *) outlineView numberOfChildrenOfItem: (id) item
@@ -158,7 +161,7 @@ typedef enum
 - (id) outlineView: (NSOutlineView *) outlineView objectValueForTableColumn: (NSTableColumn *) tableColumn byItem: (id) item
 {
     if ([[tableColumn identifier] isEqualToString: @"Check"])
-        return [NSNumber numberWithInt: [fTorrent checkForFiles: [(FileListNode *)item indexes]]];
+        return [NSNumber numberWithInteger: [fTorrent checkForFiles: [(FileListNode *)item indexes]]];
     else
         return item;
 }
@@ -186,7 +189,7 @@ typedef enum
     if ([identifier isEqualToString: @"Check"])
     {
         NSIndexSet * indexSet;
-        if ([[NSApp currentEvent] modifierFlags] & NSAlternateKeyMask)
+        if (([NSApp isOnSnowLeopardOrBetter] ? [NSEvent modifierFlags] : [[NSApp currentEvent] modifierFlags]) & NSAlternateKeyMask)
             indexSet = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [fTorrent fileCount])];
         else
             indexSet = [(FileListNode *)item indexes];
@@ -208,7 +211,7 @@ typedef enum
 {
     NSString * ident = [tableColumn identifier];
     if ([ident isEqualToString: @"Name"])
-        return [[fTorrent downloadFolder] stringByAppendingPathComponent: [(FileListNode *)item fullPath]];
+        return [fTorrent fileLocation: item];
     else if ([ident isEqualToString: @"Check"])
     {
         switch ([cell state])
@@ -311,11 +314,29 @@ typedef enum
 
 - (void) revealFile: (id) sender
 {
-    NSString * folder = [fTorrent downloadFolder];
     NSIndexSet * indexes = [fOutline selectedRowIndexes];
-    for (NSInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
-        [[NSWorkspace sharedWorkspace] selectFile: [folder stringByAppendingPathComponent:
-            [[fOutline itemAtRow: i] fullPath]] inFileViewerRootedAtPath: nil];
+    if ([NSApp isOnSnowLeopardOrBetter])
+    {
+        NSMutableArray * paths = [NSMutableArray arrayWithCapacity: [indexes count]];
+        for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
+        {
+            NSString * path = [fTorrent fileLocation: [fOutline itemAtRow: i]];
+            if (path)
+                [paths addObject: [NSURL fileURLWithPath: path]];
+        }
+        
+        if ([paths count])
+            [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs: paths];
+    }
+    else
+    {
+        for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
+        {
+            NSString * path = [fTorrent fileLocation: [fOutline itemAtRow: i]];
+            if (path)
+                [[NSWorkspace sharedWorkspace] selectFile: path inFileViewerRootedAtPath: nil];
+        }
+    }
 }
 
 #warning make real view controller (Leopard-only) so that Command-R will work
@@ -328,18 +349,16 @@ typedef enum
     
     if (action == @selector(revealFile:))
     {
-        NSString * downloadFolder = [fTorrent downloadFolder];
         NSIndexSet * indexSet = [fOutline selectedRowIndexes];
         for (NSInteger i = [indexSet firstIndex]; i != NSNotFound; i = [indexSet indexGreaterThanIndex: i])
-            if ([[NSFileManager defaultManager] fileExistsAtPath:
-                    [downloadFolder stringByAppendingPathComponent: [[fFileList objectAtIndex: i] fullPath]]])
+            if ([fTorrent fileLocation: [fFileList objectAtIndex: i]] != nil)
                 return YES;
         return NO;
     }
     
     if (action == @selector(setCheck:))
     {
-        if ([fOutline numberOfSelectedRows] <= 0)
+        if ([fOutline numberOfSelectedRows] == 0)
             return NO;
         
         NSIndexSet * indexSet = [fOutline selectedRowIndexes];
@@ -353,20 +372,20 @@ typedef enum
     
     if (action == @selector(setOnlySelectedCheck:))
     {
-        if ([fOutline numberOfSelectedRows] <= 0)
+        if ([fOutline numberOfSelectedRows] == 0)
             return NO;
         
         NSIndexSet * indexSet = [fOutline selectedRowIndexes];
         NSMutableIndexSet * itemIndexes = [NSMutableIndexSet indexSet];
         for (NSInteger i = [indexSet firstIndex]; i != NSNotFound; i = [indexSet indexGreaterThanIndex: i])
             [itemIndexes addIndexes: [[fOutline itemAtRow: i] indexes]];
-            
+        
         return [fTorrent canChangeDownloadCheckForFiles: itemIndexes];
     }
     
     if (action == @selector(setPriority:))
     {
-        if ([fOutline numberOfSelectedRows] <= 0)
+        if ([fOutline numberOfSelectedRows] == 0)
         {
             [menuItem setState: NSOffState];
             return NO;
@@ -385,13 +404,13 @@ typedef enum
                 break;
             case FILE_PRIORITY_LOW_TAG:
                 priority = TR_PRI_LOW;
+                break;
         }
         
         BOOL current = NO, canChange = NO;
-        NSIndexSet * fileIndexSet;
         for (NSInteger i = [indexSet firstIndex]; i != NSNotFound; i = [indexSet indexGreaterThanIndex: i])
         {
-            fileIndexSet = [[fOutline itemAtRow: i] indexes];
+            NSIndexSet * fileIndexSet = [[fOutline itemAtRow: i] indexes];
             if (![fTorrent canChangeDownloadCheckForFiles: fileIndexSet])
                 continue;
             
