@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: FilterButton.m 9844 2010-01-01 21:12:04Z livings124 $
+ * $Id: FilterButton.m 11417 2010-11-14 20:26:58Z livings124 $
  * 
  * Copyright (c) 2007-2010 Transmission authors and contributors
  *
@@ -23,6 +23,7 @@
  *****************************************************************************/
 
 #import "FilterButton.h"
+#import "NSStringAdditions.h"
 
 @implementation FilterButton
 
@@ -41,8 +42,10 @@
         return;
     
     fCount = count;
+    
     [self setToolTip: fCount == 1 ? NSLocalizedString(@"1 transfer", "Filter Button -> tool tip")
-        : [NSString stringWithFormat: NSLocalizedString(@"%d transfers", "Filter Bar Button -> tool tip"), fCount]];
+        : [NSString stringWithFormat: NSLocalizedString(@"%@ transfers", "Filter Bar Button -> tool tip"),
+            [NSString formattedUInteger: fCount]]];
 }
 
 @end
