@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: MessageWindowController.h 5255 2008-03-15 20:17:19Z livings124 $
+ * $Id: MessageWindowController.h 10071 2010-02-02 01:13:15Z livings124 $
  *
- * Copyright (c) 2006-2008 Transmission authors and contributors
+ * Copyright (c) 2006-2010 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -30,19 +30,21 @@
     
     IBOutlet NSPopUpButton * fLevelButton;
     IBOutlet NSButton * fSaveButton, * fClearButton;
+    IBOutlet NSSearchField * fFilterField;
     
-    NSMutableArray * fMessages;
+    NSMutableArray * fMessages, * fDisplayedMessages;
     
     NSDictionary * fAttributes;
     
     NSTimer * fTimer;
     
-    NSImage * fErrorImage, * fInfoImage, * fDebugImage;
+    NSLock * fLock;
 }
 
 - (void) updateLog: (NSTimer *) timer;
 
 - (void) changeLevel: (id) sender;
+- (void) changeFilter: (id) sender;
 - (void) clearLog: (id) sender;
 
 - (void) writeToFile: (id) sender;
