@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: NSStringAdditions.m 11351 2010-10-24 18:06:32Z livings124 $
+ * $Id: NSStringAdditions.m 11417 2010-11-14 20:26:58Z livings124 $
  *
  * Copyright (c) 2005-2010 Transmission authors and contributors
  *
@@ -46,6 +46,15 @@
 	return [self stringByAppendingString: [NSString ellipsis]];
 }
 
++ (NSString *) formattedUInteger: (NSUInteger) value
+{
+    NSNumberFormatter * numberFormatter = [[[NSNumberFormatter alloc] init] autorelease];
+    [numberFormatter setNumberStyle: NSNumberFormatterDecimalStyle];
+    [numberFormatter setMaximumFractionDigits: 0];
+    
+    return [numberFormatter stringFromNumber: [NSNumber numberWithUnsignedInteger: value]];
+}
+
 + (NSString *) stringForFileSize: (uint64_t) size
 {
     const CGFloat baseFloat = [NSApp isOnSnowLeopardOrBetter] ? 1000.0 : 1024.0;
