@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: PrefsController.m 11385 2010-11-05 22:45:38Z livings124 $
+ * $Id: PrefsController.m 11499 2010-12-09 19:50:16Z livings124 $
  *
  * Copyright (c) 2005-2010 Transmission authors and contributors
  *
@@ -62,6 +62,7 @@
 - (void) folderSheetClosed: (NSOpenPanel *) openPanel returnCode: (int) code contextInfo: (void *) info;
 - (void) incompleteFolderSheetClosed: (NSOpenPanel *) openPanel returnCode: (int) code contextInfo: (void *) info;
 - (void) importFolderSheetClosed: (NSOpenPanel *) openPanel returnCode: (int) code contextInfo: (void *) info;
+- (void) doneScriptSheetClosed: (NSOpenPanel *) openPanel returnCode: (int) code contextInfo: (void *) info;
 
 - (void) setKeychainPassword: (const char *) password forService: (const char *) service username: (const char *) username;
 
@@ -215,10 +216,19 @@ tr_session * fHandle;
     [fStalledField setIntValue: [fDefaults integerForKey: @"StalledMinutes"]];
     
     //set blocklist
+    NSString * blocklistURL = [fDefaults stringForKey: @"BlocklistURL"];
+    if (blocklistURL)
+        [fBlocklistURLField setStringValue: blocklistURL];
+    
+    [self updateBlocklistButton];
     [self updateBlocklistFields];
+    
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updateBlocklistFields)
         name: @"BlocklistUpdated" object: nil];
     
+    [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updateBlocklistURLField)
+        name: NSControlTextDidChangeNotification object: fBlocklistURLField];
+    
     //set rpc port
     [fRPCPortField setIntValue: [fDefaults integerForKey: @"RPCPort"]];
     
@@ -480,11 +490,8 @@ tr_session * fHandle;
     tr_blocklistSetEnabled(fHandle, [fDefaults boolForKey: @"BlocklistNew"]);
     
     [[BlocklistScheduler scheduler] updateSchedule];
-}
-
-- (void) setBlocklistURL: (id) sender
-{
-    tr_blocklistSetURL(fHandle, [[fDefaults stringForKey: @"BlocklistURL"] UTF8String]);
+    
+    [self updateBlocklistButton];
 }
 
 - (void) updateBlocklist: (id) sender
@@ -503,12 +510,7 @@ tr_session * fHandle;
     
     if (exists)
     {
-        NSNumberFormatter * numberFormatter = [[NSNumberFormatter alloc] init];
-        [numberFormatter setNumberStyle: NSNumberFormatterDecimalStyle];
-        [numberFormatter setMaximumFractionDigits: 0];
-        NSString * countString = [numberFormatter stringFromNumber: [NSNumber numberWithInt: tr_blocklistGetRuleCount(fHandle)]];
-        [numberFormatter release];
-        
+        NSString * countString = [NSString formattedUInteger: tr_blocklistGetRuleCount(fHandle)];
         [fBlocklistMessageField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ IP address rules in list",
             "Prefs -> blocklist -> message"), countString]];
     }
@@ -546,6 +548,24 @@ tr_session * fHandle;
         NSLocalizedString(@"Last updated", "Prefs -> blocklist -> message"), updatedDateString]];
 }
 
+- (void) updateBlocklistURLField
+{
+    NSString * blocklistString = [fBlocklistURLField stringValue];
+    
+    [fDefaults setObject: blocklistString forKey: @"BlocklistURL"];
+    tr_blocklistSetURL(fHandle, [blocklistString UTF8String]);
+    
+    [self updateBlocklistButton];
+}
+
+- (void) updateBlocklistButton
+{
+    NSString * blocklistString = [fDefaults objectForKey: @"BlocklistURL"];
+    const BOOL enable = (blocklistString && ![blocklistString isEqualToString: @""])
+                            && [fDefaults boolForKey: @"BlocklistNew"];
+    [fBlocklistButton setEnabled: enable];
+}
+
 - (void) setAutoStartDownloads: (id) sender
 {
     tr_sessionSetPaused(fHandle, ![fDefaults boolForKey: @"AutoStartDownload"]);
@@ -762,6 +782,21 @@ tr_session * fHandle;
         @selector(incompleteFolderSheetClosed:returnCode:contextInfo:) contextInfo: nil];
 }
 
+- (void) doneScriptSheetShow:(id)sender
+{
+    NSOpenPanel * panel = [NSOpenPanel openPanel];
+    
+    [panel setPrompt: NSLocalizedString(@"Select", "Preferences -> Open panel prompt")];
+    [panel setAllowsMultipleSelection: NO];
+    [panel setCanChooseFiles: YES];
+    [panel setCanChooseDirectories: NO];
+    [panel setCanCreateDirectories: NO];
+    
+    [panel beginSheetForDirectory: nil file: nil types: nil
+                   modalForWindow: [self window] modalDelegate: self didEndSelector:
+     @selector(doneScriptSheetClosed:returnCode:contextInfo:) contextInfo: nil];
+}
+
 - (void) setUseIncompleteFolder: (id) sender
 {
     tr_sessionSetIncompleteDirEnabled(fHandle, [fDefaults boolForKey: @"UseIncompleteDownloadFolder"]);
@@ -772,6 +807,17 @@ tr_session * fHandle;
     tr_sessionSetIncompleteFileNamingEnabled(fHandle, [fDefaults boolForKey: @"RenamePartialFiles"]);
 }
 
+- (void) setDoneScriptEnabled: (id) sender
+{
+    if ([fDefaults boolForKey: @"DoneScriptEnabled"] && ![[NSFileManager defaultManager] fileExistsAtPath: [fDefaults stringForKey:@"DoneScriptPath"]])
+    {
+        // enabled is set but script file doesn't exist, so prompt for one and disable until they pick one
+        [fDefaults setBool: NO forKey: @"DoneScriptEnabled"];
+        [self doneScriptSheetShow: sender];
+    }
+    tr_sessionSetTorrentDoneScriptEnabled(fHandle, [fDefaults boolForKey: @"DoneScriptEnabled"]);
+}
+
 - (void) setAutoImport: (id) sender
 {
     NSString * path;
@@ -995,6 +1041,12 @@ tr_session * fHandle;
     [fRPCAddRemoveControl setEnabled: [fRPCWhitelistTable numberOfSelectedRows] > 0 forSegment: RPC_IP_REMOVE_TAG];
 }
 
+- (void) helpForScript: (id) sender
+{
+    [[NSHelpManager sharedHelpManager] openHelpAnchor: @"script"
+        inBook: [[NSBundle mainBundle] objectForInfoDictionaryKey: @"CFBundleHelpBookName"]];
+}
+
 - (void) helpForPeers: (id) sender
 {
     [[NSHelpManager sharedHelpManager] openHelpAnchor: @"peers"
@@ -1130,6 +1182,13 @@ tr_session * fHandle;
     const NSUInteger idleLimitMin = tr_sessionGetIdleLimit(fHandle);
     [fDefaults setInteger: idleLimitMin forKey: @"IdleLimitMinutes"];
     
+    //done script
+    const BOOL doneScriptEnabled = tr_sessionIsTorrentDoneScriptEnabled(fHandle);
+    [fDefaults setBool: doneScriptEnabled forKey: @"DoneScriptEnabled"];
+    
+    NSString * doneScriptPath = [NSString stringWithUTF8String: tr_sessionGetTorrentDoneScript(fHandle)];
+    [fDefaults setObject: doneScriptPath forKey: @"DoneScriptPath"];
+    
     //update gui if loaded
     if (fHasLoaded)
     {
@@ -1164,6 +1223,8 @@ tr_session * fHandle;
         
         //speed limit schedule times and day handled by bindings
         
+        [fBlocklistURLField setStringValue: blocklistURL];
+        [self updateBlocklistButton];
         [self updateBlocklistFields];
         
         //ratio limit enabled handled by bindings
@@ -1294,6 +1355,28 @@ tr_session * fHandle;
     [fImportFolderPopUp selectItemAtIndex: 0];
 }
 
+- (void) doneScriptSheetClosed: (NSOpenPanel *) openPanel returnCode: (int) code contextInfo: (void *) info
+{
+    if (code == NSOKButton)
+    {
+        NSString * filePath = [[openPanel filenames] objectAtIndex: 0];
+        
+        if ([[NSFileManager defaultManager] fileExistsAtPath: filePath])  // script file exists
+        {
+            [fDefaults setObject: filePath forKey: @"DoneScriptPath"];
+            [fDefaults setBool: YES forKey: @"DoneScriptEnabled"];
+        }
+        else // script file doesn't exist so don't enable
+        {
+            [fDefaults setObject: nil forKey:@"DoneScriptPath"];
+            [fDefaults setBool: NO forKey: @"DoneScriptEnabled"];
+        }
+        tr_sessionSetTorrentDoneScript(fHandle, [[fDefaults stringForKey:@"DoneScriptPath"] UTF8String]);
+        tr_sessionSetTorrentDoneScriptEnabled(fHandle, [fDefaults boolForKey:@"DoneScriptEnabled"]);
+    }
+    [fDoneScriptPopUp selectItemAtIndex: 0];
+}
+
 - (void) setKeychainPassword: (const char *) password forService: (const char *) service username: (const char *) username
 {
     SecKeychainItemRef item = NULL;
