@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: TorrentCell.m 10439 2010-04-02 18:14:46Z livings124 $
+ * $Id: TorrentCell.m 11380 2010-11-02 03:36:28Z livings124 $
  *
  * Copyright (c) 2006-2010 Transmission authors and contributors
  *
@@ -610,8 +610,8 @@
     //fill an all-white bar for magnet links
     if ([torrent isMagnet])
     {
-        [[NSColor whiteColor] set];
-        NSRectFill(barRect);
+        [[NSColor colorWithCalibratedWhite: 1.0 alpha: [fDefaults boolForKey: @"SmallView"] ? 0.25 : 1.0] set];
+        NSRectFillUsingOperation(barRect, NSCompositeSourceOver);
         return;
     }
     
