@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: TorrentTableView.h 9844 2010-01-01 21:12:04Z livings124 $
+ * $Id: TorrentTableView.h 10398 2010-03-20 03:27:17Z livings124 $
  *
  * Copyright (c) 2005-2010 Transmission authors and contributors
  *
@@ -43,7 +43,7 @@
     
     IBOutlet NSMenu * fContextRow, * fContextNoRow;
     
-    NSInteger fMouseControlRow, fMouseRevealRow, fMouseActionRow, fActionPushedRow;
+    NSInteger fMouseRow, fMouseControlRow, fMouseRevealRow, fMouseActionRow, fActionPushedRow;
     NSArray * fSelectedValues;
     
     IBOutlet NSMenu * fActionMenu, * fUploadMenu, * fDownloadMenu, * fRatioMenu, * fPriorityMenu;
@@ -59,7 +59,8 @@
 - (void) removeAllCollapsedGroups;
 - (void) saveCollapsedGroups;
 
-- (void) removeButtonTrackingAreas;
+- (void) removeTrackingAreas;
+- (void) setRowHover: (NSInteger) row;
 - (void) setControlButtonHover: (NSInteger) row;
 - (void) setRevealButtonHover: (NSInteger) row;
 - (void) setActionButtonHover: (NSInteger) row;
