@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: TorrentTableView.m 11409 2010-11-14 15:16:39Z livings124 $
+ * $Id: TorrentTableView.m 11428 2010-11-21 14:45:06Z livings124 $
  *
  * Copyright (c) 2005-2010 Transmission authors and contributors
  *
@@ -26,6 +26,7 @@
 #import "Controller.h"
 #import "FileListNode.h"
 #import "NSApplicationAdditions.h"
+#import "NSStringAdditions.h"
 #import "Torrent.h"
 #import "TorrentCell.h"
 #import "TorrentGroup.h"
@@ -215,11 +216,12 @@
                 : NSLocalizedString(@"Upload speed", "Torrent table -> group row -> tooltip");
     else if (ident)
     {
-        NSInteger count = [[item torrents] count];
+        NSUInteger count = [[item torrents] count];
         if (count == 1)
             return NSLocalizedString(@"1 transfer", "Torrent table -> group row -> tooltip");
         else
-            return [NSString stringWithFormat: NSLocalizedString(@"%d transfers", "Torrent table -> group row -> tooltip"), count];
+            return [NSString stringWithFormat: NSLocalizedString(@"%@ transfers", "Torrent table -> group row -> tooltip"),
+                    [NSString formattedUInteger: count]];
     }
     else
         return nil;
