@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: app.cc 11163 2010-08-09 00:18:26Z charles $
+ * $Id: app.cc 11437 2010-11-25 03:00:25Z charles $
  */
 
 #include <cassert>
@@ -23,7 +23,6 @@
 #include <QLabel>
 #include <QLibraryInfo>
 #include <QRect>
-#include <QTranslator>
 
 #include <libtransmission/transmission.h>
 #include <libtransmission/tr-getopt.h>
@@ -94,13 +93,11 @@ MyApp :: MyApp( int& argc, char ** argv ):
     setApplicationName( MY_CONFIG_NAME );
 
     // install the qt translator
-    QTranslator qtTranslator;
     qtTranslator.load( "qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     installTranslator( &qtTranslator );
 
     // install the transmission translator
-    QTranslator appTranslator;
-    appTranslator.load( QString(MY_READABLE_NAME) + "_" + QLocale::system().name() );
+    appTranslator.load( QString(MY_CONFIG_NAME) + "_" + QLocale::system().name(), QCoreApplication::applicationDirPath() + "/translations" );
     installTranslator( &appTranslator );
 
     Formatter::initUnits( );
