@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: filterbar.cc 11406 2010-11-14 05:03:38Z charles $
+ * $Id: filterbar.cc 11423 2010-11-15 15:19:57Z charles $
  */
 
 #include <QString>
@@ -559,5 +559,5 @@ FilterBar :: recount ( )
 QString
 FilterBar :: getCountString( int n ) const
 {
-    return n>0 ? QString("%L1").arg(n) : QString();
+    return QString("%L1").arg(n);
 }
