@@ -1,13 +1,13 @@
 /*
- * This file Copyright (C) 2009-2010 Mnemosyne LLC
+ * This file Copyright (C) Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2.  Works owned by the
- * Transmission project are granted a special exemption to clause 2(b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
  *
- * $Id: session.cc 11108 2010-08-04 13:56:51Z charles $
+ * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+ *
+ * $Id: session.cc 11368 2010-10-31 17:16:12Z charles $
  */
 
 #include <cassert>
@@ -22,6 +22,7 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QSet>
+#include <QStringList>
 #include <QStyle>
 #include <QTextStream>
 
@@ -32,8 +33,8 @@
 #include <libtransmission/utils.h> /* tr_free */
 #include <libtransmission/version.h> /* LONG_VERSION */
 
+#include "add-data.h"
 #include "prefs.h"
-#include "qticonloader.h"
 #include "session.h"
 #include "session-dialog.h"
 #include "torrent.h"
@@ -140,10 +141,13 @@ Session :: updatePref( int key )
         case Prefs :: ALT_SPEED_LIMIT_UP:
         case Prefs :: BLOCKLIST_DATE:
         case Prefs :: BLOCKLIST_ENABLED:
+        case Prefs :: BLOCKLIST_URL:
         case Prefs :: DHT_ENABLED:
         case Prefs :: DOWNLOAD_DIR:
         case Prefs :: DSPEED:
         case Prefs :: DSPEED_ENABLED:
+        case Prefs :: IDLE_LIMIT:
+        case Prefs :: IDLE_LIMIT_ENABLED:
         case Prefs :: INCOMPLETE_DIR:
         case Prefs :: INCOMPLETE_DIR_ENABLED:
         case Prefs :: LPD_ENABLED:
@@ -189,7 +193,7 @@ Session :: updatePref( int key )
 
         case Prefs :: RPC_AUTH_REQUIRED:
             if( mySession )
-                tr_sessionSetRPCEnabled( mySession, myPrefs.getBool(key) );
+                tr_sessionSetRPCPasswordEnabled( mySession, myPrefs.getBool(key) );
             break;
         case Prefs :: RPC_ENABLED:
             if( mySession )
@@ -418,6 +422,21 @@ Session :: torrentSet( const QSet<int>& ids, const QString& key, bool value )
     tr_bencFree( &top );
 }
 
+void
+Session :: torrentSet( const QSet<int>& ids, const QString& key, const QStringList& value )
+{
+    tr_benc top;
+    tr_bencInitDict( &top, 2 );
+    tr_bencDictAddStr( &top, "method", "torrent-set" );
+    tr_benc * args = tr_bencDictAddDict( &top, "arguments", 2 );
+    addOptionalIds( args, ids );
+    tr_benc * list( tr_bencDictAddList( args, key.toUtf8().constData(), value.size( ) ) );
+    foreach( const QString str, value )
+        tr_bencListAddStr( list, str.toUtf8().constData() );
+    exec( &top );
+    tr_bencFree( &top );
+}
+
 void
 Session :: torrentSet( const QSet<int>& ids, const QString& key, const QList<int>& value )
 {
@@ -433,6 +452,21 @@ Session :: torrentSet( const QSet<int>& ids, const QString& key, const QList<int
     tr_bencFree( &top );
 }
 
+void
+Session :: torrentSet( const QSet<int>& ids, const QString& key, const QPair<int,QString>& value )
+{
+    tr_benc top;
+    tr_bencInitDict( &top, 2 );
+    tr_bencDictAddStr( &top, "method", "torrent-set" );
+    tr_benc * args( tr_bencDictAddDict( &top, "arguments", 2 ) );
+    addOptionalIds( args, ids );
+    tr_benc * list( tr_bencDictAddList( args, key.toUtf8().constData(), 2 ) );
+    tr_bencListAddInt( list, value.first );
+    tr_bencListAddStr( list, value.second.toUtf8().constData() );
+    exec( &top );
+    tr_bencFree( &top );
+}
+
 void
 Session :: torrentSetLocation( const QSet<int>& ids, const QString& location, bool doMove )
 {
@@ -752,12 +786,6 @@ Session :: parseResponse( const char * json, size_t jsonLength )
                                                            QString::fromUtf8(str),
                                                            QMessageBox::Close,
                                                            QApplication::activeWindow());
-                        QPixmap pixmap;
-                        QIcon icon = QtIconLoader :: icon( "dialog-information" );
-                        if( !icon.isNull( ) ) {
-                            const int size = QApplication::style()->pixelMetric( QStyle::PM_LargeIconSize );
-                            d->setIconPixmap( icon.pixmap( size, size ) );
-                        }
                         connect( d, SIGNAL(rejected()), d, SLOT(deleteLater()) );
                         d->show( );
                     }
@@ -907,54 +935,38 @@ Session :: setBlocklistSize( int64_t i )
 }
 
 void
-Session :: addTorrent( QString filename )
+Session :: addTorrent( const AddData& addMe )
 {
-    addTorrent( filename, myPrefs.getString( Prefs::DOWNLOAD_DIR ) );
-}
+    const QByteArray b64 = addMe.toBase64();
 
-namespace
-{
-    bool isLink( const QString& str )
-    {
-        return Utils::isMagnetLink(str) || Utils::isURL(str);
+    tr_benc top, *args;
+    tr_bencInitDict( &top, 2 );
+    tr_bencDictAddStr( &top, "method", "torrent-add" );
+    args = tr_bencDictAddDict( &top, "arguments", 2 );
+    tr_bencDictAddBool( args, "paused", !myPrefs.getBool( Prefs::START ) );
+    switch( addMe.type ) {
+        case AddData::MAGNET:   tr_bencDictAddStr( args, "filename", addMe.magnet.toUtf8().constData() ); break;
+        case AddData::URL:      tr_bencDictAddStr( args, "filename", addMe.url.toString().toUtf8().constData() ); break;
+        case AddData::FILENAME: /* fall-through */
+        case AddData::METAINFO: tr_bencDictAddRaw( args, "metainfo", b64.constData(), b64.size() ); break;
+        default: std::cerr << "Unhandled AddData type: " << addMe.type << std::endl;
     }
+    exec( &top );
+    tr_bencFree( &top );
 }
 
 void
-Session :: addTorrent( QString key, QString localPath )
+Session :: addNewlyCreatedTorrent( const QString& filename, const QString& localPath )
 {
+    const QByteArray b64 = AddData(filename).toBase64();
+
     tr_benc top, *args;
     tr_bencInitDict( &top, 2 );
     tr_bencDictAddStr( &top, "method", "torrent-add" );
     args = tr_bencDictAddDict( &top, "arguments", 3 );
     tr_bencDictAddStr( args, "download-dir", qPrintable(localPath) );
     tr_bencDictAddBool( args, "paused", !myPrefs.getBool( Prefs::START ) );
-
-    // figure out what to do with "key"....
-    bool keyHandled = false;
-    if( !keyHandled && isLink( key  )) {
-        tr_bencDictAddStr( args, "filename", key.toUtf8().constData() );
-        keyHandled = true; // it's a URL or magnet link...
-    }
-    if( !keyHandled ) {
-        QFile file( key );
-        file.open( QIODevice::ReadOnly );
-        const QByteArray raw( file.readAll( ) );
-        file.close( );
-        if( !raw.isEmpty( ) ) {
-            int b64len = 0;
-            char * b64 = tr_base64_encode( raw.constData(), raw.size(), &b64len );
-            tr_bencDictAddRaw( args, "metainfo", b64, b64len  );
-            tr_free( b64 );
-            keyHandled = true; // it's a local file...
-        }
-    }
-    if( !keyHandled ) {
-        const QByteArray tmp = key.toUtf8();
-        tr_bencDictAddRaw( args, "metainfo", tmp.constData(), tmp.length() );
-        keyHandled = true; // treat it as base64
-    }
-
+    tr_bencDictAddRaw( args, "metainfo", b64.constData(), b64.size() );
     exec( &top );
     tr_bencFree( &top );
 }
