@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: torrent.cc 11240 2010-09-20 13:46:08Z charles $
+ * $Id: torrent.cc 11491 2010-12-08 15:45:43Z charles $
  */
 
 #include <cassert>
@@ -368,6 +368,20 @@ Torrent :: hasTrackerSubstring( const QString& substr ) const
     return false;
 }
 
+int
+Torrent :: compareSeedRatio( const Torrent& that ) const
+{
+    double a;
+    double b;
+    const bool has_a = getSeedRatio( a );
+    const bool has_b = that.getSeedRatio( b );
+    if( !has_a && !has_b ) return 0;
+    if( !has_a || !has_b ) return has_a ? -1 : 1;
+    if( a < b ) return -1;
+    if( a > b ) return 1;
+    return 0;
+}
+
 int
 Torrent :: compareRatio( const Torrent& that ) const
 {
@@ -523,8 +537,7 @@ Torrent :: update( tr_benc * d )
 
     if( tr_bencDictFindList( d, "fileStats", &files ) ) {
         const int n = tr_bencListSize( files );
-        assert( n == myFiles.size( ) );
-        for( int i=0; i<n; ++i ) {
+        for( int i=0; i<n && i<myFiles.size(); ++i ) {
             int64_t intVal;
             tr_bool boolVal;
             tr_benc * child = tr_bencListChild( files, i );
