@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009 by Juliusz Chroboczek
+Copyright (c) 2010 by Juliusz Chroboczek
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -39,10 +39,17 @@ THE SOFTWARE.
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/time.h>
+
+#ifndef WIN32
 #include <arpa/inet.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#else
+#include <w32api.h>
+#define WINVER WindowsXP
+#include <ws2tcpip.h>
+#endif
 
 #include "dht.h"
 
@@ -56,6 +63,48 @@ THE SOFTWARE.
 #define MSG_CONFIRM 0
 #endif
 
+#ifdef WIN32
+
+#define EAFNOSUPPORT WSAEAFNOSUPPORT
+#define EAGAIN WSAEWOULDBLOCK
+static int
+set_nonblocking(int fd, int nonblocking)
+{
+    int rc;
+
+    unsigned long mode = !!nonblocking;
+    rc = ioctlsocket(fd, FIONBIO, &mode);
+    if(rc != 0)
+        errno = WSAGetLastError();
+    return (rc == 0 ? 0 : -1);
+}
+
+static int
+random(void)
+{
+    return rand();
+}
+extern const char *inet_ntop(int, const void *, char *, socklen_t);
+
+#else
+
+static int
+set_nonblocking(int fd, int nonblocking)
+{
+    int rc;
+    rc = fcntl(fd, F_GETFL, 0);
+    if(rc < 0)
+        return -1;
+
+    rc = fcntl(fd, F_SETFL, nonblocking?(rc | O_NONBLOCK):(rc & ~O_NONBLOCK));
+    if(rc < 0)
+        return -1;
+
+    return 0;
+}
+
+#endif
+
 /* We set sin_family to 0 to mark unused slots. */
 #if AF_INET == 0 || AF_INET6 == 0
 #error You lose
@@ -262,9 +311,9 @@ static struct timeval now;
 static time_t mybucket_grow_time, mybucket6_grow_time;
 static time_t expire_stuff_time;
 
-#define MAX_LEAKY_BUCKET_TOKENS 40
-static time_t leaky_bucket_time;
-static int leaky_bucket_tokens;
+#define MAX_TOKEN_BUCKET_TOKENS 40
+static time_t token_bucket_time;
+static int token_bucket_tokens;
 
 FILE *dht_debug = NULL;
 
@@ -331,7 +380,7 @@ is_martian(struct sockaddr *sa)
 /* Forget about the ``XOR-metric''.  An id is just a path from the
    root of the tree, so bits are numbered from the start. */
 
-static inline int
+static int
 id_cmp(const unsigned char *restrict id1, const unsigned char *restrict id2)
 {
     /* Memcmp is guaranteed to perform an unsigned comparison. */
@@ -741,7 +790,7 @@ new_node(const unsigned char *id, struct sockaddr *sa, int salen, int confirm)
 
         if(split) {
             debugf("Splitting.\n");
-            b = split_bucket(b);
+            split_bucket(b);
             return new_node(id, sa, salen, confirm);
         }
 
@@ -988,7 +1037,7 @@ search_step(struct search *sr, dht_callback *callback, void *closure)
                 /* A proposed extension to the protocol consists in
                    omitting the token when storage tables are full.  While
                    I don't think this makes a lot of sense -- just sending
-                   a positive reply is just as good, let's deal with it. */
+                   a positive reply is just as good --, let's deal with it. */
                 if(n->token_len == 0)
                     n->acked = 1;
                 if(!n->acked) {
@@ -1175,10 +1224,24 @@ static int
 storage_store(const unsigned char *id, struct sockaddr *sa)
 {
     int i, len;
-    struct storage *st = storage;
+    struct storage *st;
     unsigned char *ip;
     unsigned short port;
 
+    if(sa->sa_family == AF_INET) {
+        struct sockaddr_in *sin = (struct sockaddr_in*)sa;
+        ip = (unsigned char*)&sin->sin_addr;
+        len = 4;
+        port = ntohs(sin->sin_port);
+    } else if(sa->sa_family == AF_INET6) {
+        struct sockaddr_in6 *sin6 = (struct sockaddr_in6*)sa;
+        ip = (unsigned char*)&sin6->sin6_addr;
+        len = 16;
+        port = ntohs(sin6->sin6_port);
+    } else {
+        return -1;
+    }
+
     st = find_storage(id);
 
     if(st == NULL) {
@@ -1192,18 +1255,6 @@ storage_store(const unsigned char *id, struct sockaddr *sa)
         numstorage++;
     }
 
-    if(sa->sa_family == AF_INET) {
-        struct sockaddr_in *sin = (struct sockaddr_in*)sa;
-        ip = (unsigned char*)&sin->sin_addr;
-        len = 4;
-        port = ntohs(sin->sin_port);
-    } else if(sa->sa_family == AF_INET6) {
-        struct sockaddr_in6 *sin6 = (struct sockaddr_in6*)sa;
-        ip = (unsigned char*)&sin6->sin6_addr;
-        len = 16;
-        port = ntohs(sin6->sin6_port);
-    }
-
     for(i = 0; i < st->numpeers; i++) {
         if(st->peers[i].port == port && st->peers[i].len == len &&
            memcmp(st->peers[i].ip, ip, len) == 0)
@@ -1548,11 +1599,7 @@ dht_init(int s, int s6, const unsigned char *id, const unsigned char *v)
             return -1;
         buckets->af = AF_INET;
 
-        rc = fcntl(s, F_GETFL, 0);
-        if(rc < 0)
-            goto fail;
-
-        rc = fcntl(s, F_SETFL, (rc | O_NONBLOCK));
+        rc = set_nonblocking(s, 1);
         if(rc < 0)
             goto fail;
     }
@@ -1563,11 +1610,7 @@ dht_init(int s, int s6, const unsigned char *id, const unsigned char *v)
             return -1;
         buckets6->af = AF_INET6;
 
-        rc = fcntl(s6, F_GETFL, 0);
-        if(rc < 0)
-            goto fail;
-
-        rc = fcntl(s6, F_SETFL, (rc | O_NONBLOCK));
+        rc = set_nonblocking(s6, 1);
         if(rc < 0)
             goto fail;
     }
@@ -1592,8 +1635,8 @@ dht_init(int s, int s6, const unsigned char *id, const unsigned char *v)
 
     next_blacklisted = 0;
 
-    leaky_bucket_time = now.tv_sec;
-    leaky_bucket_tokens = MAX_LEAKY_BUCKET_TOKENS;
+    token_bucket_time = now.tv_sec;
+    token_bucket_tokens = MAX_TOKEN_BUCKET_TOKENS;
 
     memset(secret, 0, sizeof(secret));
     rc = rotate_secrets();
@@ -1655,18 +1698,18 @@ dht_uninit(int dofree)
 /* Rate control for requests we receive. */
 
 static int
-leaky_bucket(void)
+token_bucket(void)
 {
-    if(leaky_bucket_tokens == 0) {
-        leaky_bucket_tokens = MIN(MAX_LEAKY_BUCKET_TOKENS,
-                                  4 * (now.tv_sec - leaky_bucket_time));
-        leaky_bucket_time = now.tv_sec;
+    if(token_bucket_tokens == 0) {
+        token_bucket_tokens = MIN(MAX_TOKEN_BUCKET_TOKENS,
+                                  4 * (now.tv_sec - token_bucket_time));
+        token_bucket_time = now.tv_sec;
     }
 
-    if(leaky_bucket_tokens == 0)
+    if(token_bucket_tokens == 0)
         return 0;
 
-    leaky_bucket_tokens--;
+    token_bucket_tokens--;
     return 1;
 }
 
@@ -1804,7 +1847,7 @@ dht_periodic(int available, time_t *tosleep,
         unsigned short port;
         unsigned char values[2048], values6[2048];
         int values_len = 2048, values6_len = 2048;
-        int want, want4, want6;
+        int want;
         struct sockaddr_storage source_storage;
         struct sockaddr *source = (struct sockaddr*)&source_storage;
         socklen_t sourcelen = sizeof(source_storage);
@@ -1869,20 +1912,12 @@ dht_periodic(int available, time_t *tosleep,
 
         if(message > REPLY) {
             /* Rate limit requests. */
-            if(!leaky_bucket()) {
+            if(!token_bucket()) {
                 debugf("Dropping request due to rate limiting.\n");
                 goto dontread;
             }
         }
 
-        if(want > 0) {
-            want4 = (want & WANT4);
-            want6 = (want & WANT6);
-        } else {
-            want4 = source->sa_family == AF_INET;
-            want6 = source->sa_family == AF_INET6;
-        }
-
         switch(message) {
         case REPLY:
             if(tid_len != 4) {
@@ -2373,11 +2408,6 @@ send_nodes_peers(struct sockaddr *sa, int salen,
 
     rc = snprintf(buf + i, 2048 - i, "d1:rd2:id20:"); INC(i, rc, 2048);
     COPY(buf, i, myid, 20, 2048);
-    if(token_len > 0) {
-        rc = snprintf(buf + i, 2048 - i, "5:token%d:", token_len);
-        INC(i, rc, 2048);
-        COPY(buf, i, token, token_len, 2048);
-    }
     if(nodes_len > 0) {
         rc = snprintf(buf + i, 2048 - i, "5:nodes%d:", nodes_len);
         INC(i, rc, 2048);
@@ -2388,6 +2418,11 @@ send_nodes_peers(struct sockaddr *sa, int salen,
          INC(i, rc, 2048);
          COPY(buf, i, nodes6, nodes6_len, 2048);
     }
+    if(token_len > 0) {
+        rc = snprintf(buf + i, 2048 - i, "5:token%d:", token_len);
+        INC(i, rc, 2048);
+        COPY(buf, i, token, token_len, 2048);
+    }
 
     if(st && st->numpeers > 0) {
         /* We treat the storage as a circular list, and serve a randomly
@@ -2827,8 +2862,10 @@ parse_message(const unsigned char *buf, int buflen,
             if(values6_len)
                 *values6_len = j6;
         } else {
-            *values_len = 0;
-            *values6_len = 0;
+            if(values_len)
+                *values_len = 0;
+            if(values6_len)
+                *values6_len = 0;
         }
     }
 
