@@ -1,4 +1,4 @@
-/* $Id: getgateway.h,v 1.2 2007/11/22 18:01:37 nanard Exp $ */
+/* $Id: getgateway.h,v 1.4 2009/12/19 12:00:00 nanard Exp $ */
 /* libnatpmp
  * Copyright (c) 2007, Thomas BERNARD <miniupnp@free.fr>
  *
@@ -16,10 +16,21 @@
 #ifndef __GETGATEWAY_H__
 #define __GETGATEWAY_H__
 
+#ifdef WIN32
+#if !defined(_MSC_VER)
+#include <stdint.h>
+#else
+typedef unsigned long uint32_t;
+typedef unsigned short uint16_t;
+#endif
+#define in_addr_t uint32_t
+#endif
+#include "declspec.h"
+
 /* getdefaultgateway() :
  * return value :
  *    0 : success
  *   -1 : failure    */
-int getdefaultgateway(in_addr_t * addr);
+LIBSPEC int getdefaultgateway(in_addr_t * addr);
 
 #endif
